/********************************************************************************
** Form generated from reading UI file 'qwaitedplayersetupdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QWAITEDPLAYERSETUPDIALOG_H
#define UI_QWAITEDPLAYERSETUPDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <klocalizedstring.h>
#include "kpassworddialog.h"

QT_BEGIN_NAMESPACE

class Ui_QWaitedPlayerSetupDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *TextLabel1;
    QComboBox *waitedPlayersCombo;
    QLabel *passwordLabel;
    QLineEdit *passwordEdit;
    QPushButton *PushButton1;

    void setupUi(QDialog *QWaitedPlayerSetupDialog)
    {
        if (QWaitedPlayerSetupDialog->objectName().isEmpty())
            QWaitedPlayerSetupDialog->setObjectName("QWaitedPlayerSetupDialog");
        QWaitedPlayerSetupDialog->resize(236, 126);
        gridLayout = new QGridLayout(QWaitedPlayerSetupDialog);
        gridLayout->setObjectName("gridLayout");
        TextLabel1 = new QLabel(QWaitedPlayerSetupDialog);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setFrameShape(QFrame::NoFrame);
        TextLabel1->setWordWrap(false);

        gridLayout->addWidget(TextLabel1, 0, 0, 1, 2);

        waitedPlayersCombo = new QComboBox(QWaitedPlayerSetupDialog);
        waitedPlayersCombo->setObjectName("waitedPlayersCombo");
        waitedPlayersCombo->setDuplicatesEnabled(false);

        gridLayout->addWidget(waitedPlayersCombo, 1, 0, 1, 2);

        passwordLabel = new QLabel(QWaitedPlayerSetupDialog);
        passwordLabel->setObjectName("passwordLabel");
        passwordLabel->setWordWrap(false);

        gridLayout->addWidget(passwordLabel, 2, 0, 1, 1);

        passwordEdit = new QLineEdit(QWaitedPlayerSetupDialog);
        passwordEdit->setObjectName("passwordEdit");
        passwordEdit->setMaxLength(8);
        passwordEdit->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(passwordEdit, 3, 0, 1, 1);

        PushButton1 = new QPushButton(QWaitedPlayerSetupDialog);
        PushButton1->setObjectName("PushButton1");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-ok")));
        PushButton1->setIcon(icon);

        gridLayout->addWidget(PushButton1, 3, 1, 1, 1);


        retranslateUi(QWaitedPlayerSetupDialog);

        QMetaObject::connectSlotsByName(QWaitedPlayerSetupDialog);
    } // setupUi

    void retranslateUi(QDialog *QWaitedPlayerSetupDialog)
    {
        QWaitedPlayerSetupDialog->setWindowTitle(tr2i18n("Saved Player Selection", nullptr));
        TextLabel1->setText(tr2i18n("Please select your saved player:", nullptr));
#if QT_CONFIG(tooltip)
        waitedPlayersCombo->setToolTip(tr2i18n("Choose your nation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        waitedPlayersCombo->setWhatsThis(tr2i18n("A combo box that lists currently available nations.\n"
"Choose one of them. It will be your nation during the game", nullptr));
#endif // QT_CONFIG(whatsthis)
        passwordLabel->setText(tr2i18n("Enter your password:", nullptr));
        PushButton1->setText(tr2i18n("OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QWaitedPlayerSetupDialog: public Ui_QWaitedPlayerSetupDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QWAITEDPLAYERSETUPDIALOG_H

