/*
Enables to choose the number of players and the game skin used
*/

/********************************************************************************
** Form generated from reading UI file 'newGameDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWGAMEDIALOG_H
#define UI_NEWGAMEDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KNSWidgets/Button"

QT_BEGIN_NAMESPACE

class Ui_NewGameDialog
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *textLabel1;
    QSpinBox *playersNumberEntry;
    QVBoxLayout *verticalLayout;
    QLabel *localPlayersNumberLabel;
    QSpinBox *localPlayersNumberEntry;
    QVBoxLayout *verticalLayout_3;
    QLabel *tcpPortLabel;
    QSpinBox *tcpPortEntry;
    QFrame *line1;
    QHBoxLayout *horizontalLayout_4;
    QLabel *textLabel2;
    QComboBox *skinCombo;
    KNSWidgets::Button *ghnsbutton;
    QLabel *skinDescLabel;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *goalGroup;
    QVBoxLayout *vboxLayout;
    QRadioButton *radioWorld;
    QRadioButton *radioGoal;
    QSpacerItem *spacerItem;
    QLabel *skinSnapshotPixmap;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *nextButton;

    void setupUi(QWidget *NewGameDialog)
    {
        if (NewGameDialog->objectName().isEmpty())
            NewGameDialog->setObjectName("NewGameDialog");
        NewGameDialog->resize(615, 417);
        NewGameDialog->setProperty("sizeGripEnabled", QVariant(true));
        verticalLayout_4 = new QVBoxLayout(NewGameDialog);
        verticalLayout_4->setObjectName("verticalLayout_4");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        textLabel1 = new QLabel(NewGameDialog);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        verticalLayout_2->addWidget(textLabel1);

        playersNumberEntry = new QSpinBox(NewGameDialog);
        playersNumberEntry->setObjectName("playersNumberEntry");

        verticalLayout_2->addWidget(playersNumberEntry);


        horizontalLayout->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        localPlayersNumberLabel = new QLabel(NewGameDialog);
        localPlayersNumberLabel->setObjectName("localPlayersNumberLabel");

        verticalLayout->addWidget(localPlayersNumberLabel);

        localPlayersNumberEntry = new QSpinBox(NewGameDialog);
        localPlayersNumberEntry->setObjectName("localPlayersNumberEntry");

        verticalLayout->addWidget(localPlayersNumberEntry);


        horizontalLayout->addLayout(verticalLayout);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        tcpPortLabel = new QLabel(NewGameDialog);
        tcpPortLabel->setObjectName("tcpPortLabel");

        verticalLayout_3->addWidget(tcpPortLabel);

        tcpPortEntry = new QSpinBox(NewGameDialog);
        tcpPortEntry->setObjectName("tcpPortEntry");
        tcpPortEntry->setMinimum(1);
        tcpPortEntry->setMaximum(32767);
        tcpPortEntry->setValue(20000);

        verticalLayout_3->addWidget(tcpPortEntry);


        horizontalLayout->addLayout(verticalLayout_3);


        verticalLayout_4->addLayout(horizontalLayout);

        line1 = new QFrame(NewGameDialog);
        line1->setObjectName("line1");
        line1->setFrameShape(QFrame::HLine);
        line1->setFrameShadow(QFrame::Sunken);
        line1->setFrameShape(QFrame::Shape::HLine);

        verticalLayout_4->addWidget(line1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        textLabel2 = new QLabel(NewGameDialog);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        horizontalLayout_4->addWidget(textLabel2);

        skinCombo = new QComboBox(NewGameDialog);
        skinCombo->setObjectName("skinCombo");

        horizontalLayout_4->addWidget(skinCombo);

        ghnsbutton = new KNSWidgets::Button(NewGameDialog);
        ghnsbutton->setObjectName("ghnsbutton");

        horizontalLayout_4->addWidget(ghnsbutton);


        verticalLayout_4->addLayout(horizontalLayout_4);

        skinDescLabel = new QLabel(NewGameDialog);
        skinDescLabel->setObjectName("skinDescLabel");
        skinDescLabel->setText(QString::fromUtf8("skinDescLabel"));
        skinDescLabel->setAlignment(Qt::AlignVCenter);
        skinDescLabel->setWordWrap(false);

        verticalLayout_4->addWidget(skinDescLabel);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        goalGroup = new QGroupBox(NewGameDialog);
        goalGroup->setObjectName("goalGroup");
        vboxLayout = new QVBoxLayout(goalGroup);
        vboxLayout->setObjectName("vboxLayout");
        radioWorld = new QRadioButton(goalGroup);
        radioWorld->setObjectName("radioWorld");

        vboxLayout->addWidget(radioWorld);

        radioGoal = new QRadioButton(goalGroup);
        radioGoal->setObjectName("radioGoal");
        radioGoal->setChecked(true);

        vboxLayout->addWidget(radioGoal);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        horizontalLayout_3->addWidget(goalGroup);

        skinSnapshotPixmap = new QLabel(NewGameDialog);
        skinSnapshotPixmap->setObjectName("skinSnapshotPixmap");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Ignored);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skinSnapshotPixmap->sizePolicy().hasHeightForWidth());
        skinSnapshotPixmap->setSizePolicy(sizePolicy);
        skinSnapshotPixmap->setScaledContents(true);
        skinSnapshotPixmap->setWordWrap(false);

        horizontalLayout_3->addWidget(skinSnapshotPixmap);


        verticalLayout_4->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cancelButton = new QPushButton(NewGameDialog);
        cancelButton->setObjectName("cancelButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-cancel")));
        cancelButton->setIcon(icon);

        horizontalLayout_2->addWidget(cancelButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        nextButton = new QPushButton(NewGameDialog);
        nextButton->setObjectName("nextButton");

        horizontalLayout_2->addWidget(nextButton);


        verticalLayout_4->addLayout(horizontalLayout_2);

        QWidget::setTabOrder(skinCombo, playersNumberEntry);
        QWidget::setTabOrder(playersNumberEntry, radioWorld);
        QWidget::setTabOrder(radioWorld, radioGoal);

        retranslateUi(NewGameDialog);

        QMetaObject::connectSlotsByName(NewGameDialog);
    } // setupUi

    void retranslateUi(QWidget *NewGameDialog)
    {
        textLabel1->setText(tr2i18n("Total number of players:", nullptr));
#if QT_CONFIG(tooltip)
        playersNumberEntry->setToolTip(tr2i18n("Spin this to choose the number of players.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        playersNumberEntry->setWhatsThis(tr2i18n("A spin box to choose the number of players", nullptr));
#endif // QT_CONFIG(whatsthis)
        localPlayersNumberLabel->setText(tr2i18n("Number of local players:", nullptr));
        tcpPortLabel->setText(tr2i18n("TCP port on which to offer connections:", nullptr));
        textLabel2->setText(tr2i18n("Skin:", nullptr));
#if QT_CONFIG(tooltip)
        skinCombo->setToolTip(tr2i18n("Choose the skin (map, nationalities, etc.) to use for this game.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        skinCombo->setWhatsThis(tr2i18n("A combo listing all the available skins.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ghnsbutton->setText(tr2i18n("Download New Skins\342\200\246", nullptr));
        ghnsbutton->setConfigFile(tr2i18n("ksirk.knsrc", nullptr));
        goalGroup->setTitle(tr2i18n("Goal Type", nullptr));
#if QT_CONFIG(tooltip)
        radioWorld->setToolTip(tr2i18n("Choose this for players to have to conquer all the world to win.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        radioWorld->setWhatsThis(tr2i18n("In this mode, a player will have to conquer all the world to win.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioWorld->setText(tr2i18n("World con&quest", nullptr));
#if QT_CONFIG(tooltip)
        radioGoal->setToolTip(tr2i18n("Choose this to have a goal assigned to each player.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        radioGoal->setWhatsThis(tr2i18n("In this mode, a goal will be assigned to each player, which he will have to reach in order to win.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioGoal->setText(tr2i18n("Reach a goa&l", nullptr));
#if QT_CONFIG(shortcut)
        radioGoal->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        skinSnapshotPixmap->setText(QString());
        cancelButton->setText(tr2i18n("Cancel", nullptr));
        nextButton->setText(tr2i18n("Next", nullptr));
        (void)NewGameDialog;
    } // retranslateUi

};

namespace Ui {
    class NewGameDialog: public Ui_NewGameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWGAMEDIALOG_H

