/****************************************************************************
** Meta object code from reading C++ file 'kplayersetupwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksirk-26.07.80/ksirk/Dialogs/kplayersetupwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kplayersetupwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Ksirk18KPlayerSetupWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Ksirk::KPlayerSetupWidget::qt_create_metaobjectdata<qt_meta_tag_ZN5Ksirk18KPlayerSetupWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ksirk::KPlayerSetupWidget",
        "next",
        "",
        "previous",
        "cancel",
        "slotNext",
        "slotPrevious",
        "slotCancel",
        "slotPlayerJoinedGame",
        "KPlayer*",
        "player",
        "slotNationChanged",
        "slotNameEdited",
        "text"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'next'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previous'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cancel'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNext'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrevious'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCancel'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlayerJoinedGame'
        QtMocHelpers::SlotData<void(KPlayer *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotNationChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNameEdited'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPlayerSetupWidget, qt_meta_tag_ZN5Ksirk18KPlayerSetupWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ksirk::KPlayerSetupWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk18KPlayerSetupWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk18KPlayerSetupWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Ksirk18KPlayerSetupWidgetE_t>.metaTypes,
    nullptr
} };

void Ksirk::KPlayerSetupWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPlayerSetupWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->next(); break;
        case 1: _t->previous(); break;
        case 2: _t->cancel(); break;
        case 3: _t->slotNext(); break;
        case 4: _t->slotPrevious(); break;
        case 5: _t->slotCancel(); break;
        case 6: _t->slotPlayerJoinedGame((*reinterpret_cast<std::add_pointer_t<KPlayer*>>(_a[1]))); break;
        case 7: _t->slotNationChanged(); break;
        case 8: _t->slotNameEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KPlayerSetupWidget::*)()>(_a, &KPlayerSetupWidget::next, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KPlayerSetupWidget::*)()>(_a, &KPlayerSetupWidget::previous, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KPlayerSetupWidget::*)()>(_a, &KPlayerSetupWidget::cancel, 2))
            return;
    }
}

const QMetaObject *Ksirk::KPlayerSetupWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::KPlayerSetupWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk18KPlayerSetupWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::QPlayerSetupWidget"))
        return static_cast< Ui::QPlayerSetupWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ksirk::KPlayerSetupWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Ksirk::KPlayerSetupWidget::next()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Ksirk::KPlayerSetupWidget::previous()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ksirk::KPlayerSetupWidget::cancel()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
