/********************************************************************************
** Form generated from reading UI file 'tcpconnectwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TCPCONNECTWIDGET_H
#define UI_TCPCONNECTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpassworddialog.h"

QT_BEGIN_NAMESPACE

class Ui_TcpConnectWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *hostLabel;
    QLabel *portLabel;
    QSpacerItem *horizontalSpacer_2;
    QSpinBox *portEdit;
    QLineEdit *hostEdit;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *previousButton;
    QPushButton *nextButton;

    void setupUi(QWidget *TcpConnectWidget)
    {
        if (TcpConnectWidget->objectName().isEmpty())
            TcpConnectWidget->setObjectName("TcpConnectWidget");
        TcpConnectWidget->resize(560, 393);
        verticalLayout = new QVBoxLayout(TcpConnectWidget);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        hostLabel = new QLabel(TcpConnectWidget);
        hostLabel->setObjectName("hostLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(hostLabel->sizePolicy().hasHeightForWidth());
        hostLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(hostLabel, 0, 0, 1, 1);

        portLabel = new QLabel(TcpConnectWidget);
        portLabel->setObjectName("portLabel");
        sizePolicy.setHeightForWidth(portLabel->sizePolicy().hasHeightForWidth());
        portLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(portLabel, 1, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        portEdit = new QSpinBox(TcpConnectWidget);
        portEdit->setObjectName("portEdit");
        portEdit->setMinimum(1);
        portEdit->setMaximum(32767);
        portEdit->setValue(20000);

        gridLayout->addWidget(portEdit, 1, 1, 1, 1);

        hostEdit = new QLineEdit(TcpConnectWidget);
        hostEdit->setObjectName("hostEdit");

        gridLayout->addWidget(hostEdit, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        cancelButton = new QPushButton(TcpConnectWidget);
        cancelButton->setObjectName("cancelButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-cancel")));
        cancelButton->setIcon(icon);

        horizontalLayout_3->addWidget(cancelButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        previousButton = new QPushButton(TcpConnectWidget);
        previousButton->setObjectName("previousButton");

        horizontalLayout_3->addWidget(previousButton);

        nextButton = new QPushButton(TcpConnectWidget);
        nextButton->setObjectName("nextButton");

        horizontalLayout_3->addWidget(nextButton);


        verticalLayout->addLayout(horizontalLayout_3);


        retranslateUi(TcpConnectWidget);

        QMetaObject::connectSlotsByName(TcpConnectWidget);
    } // setupUi

    void retranslateUi(QWidget *TcpConnectWidget)
    {
        hostLabel->setText(tr2i18n("Host:", nullptr));
        portLabel->setText(tr2i18n("Port:", nullptr));
        hostEdit->setText(tr2i18n("localhost", nullptr));
        cancelButton->setText(tr2i18n("Cancel", nullptr));
        previousButton->setText(tr2i18n("Previous", nullptr));
        nextButton->setText(tr2i18n("Next", nullptr));
        (void)TcpConnectWidget;
    } // retranslateUi

};

namespace Ui {
    class TcpConnectWidget: public Ui_TcpConnectWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TCPCONNECTWIDGET_H

