// This file is generated by kconfig_compiler_kf6 from ksirkskineditorsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef KSIRKSKINEDITOR_KSIRKSKINEDITORSETTINGS_H
#define KSIRKSKINEDITOR_KSIRKSKINEDITORSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace KsirkSkinEditor {

class KsirkSkinEditorSettings : public KConfigSkeleton
{
  public:
    static KsirkSkinEditorSettings *self();
    ~KsirkSkinEditorSettings() override;

  protected:
    KsirkSkinEditorSettings();
    friend class KsirkSkinEditorSettingsHelper;

};

}

#endif

