/********************************************************************************
** Form generated from reading UI file 'ksirkcountrydefinition.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKCOUNTRYDEFINITION_H
#define UI_KSIRKCOUNTRYDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KsirkCountryDefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *label_5;
    QLabel *label_6;
    QLabel *label_7;
    QSpinBox *infantryx;
    QLabel *label_8;
    QSpinBox *infantryy;
    QLabel *label_9;
    QSpinBox *cavalryx;
    QLabel *label_10;
    QSpinBox *cavalryy;
    QLabel *label_12;
    QLabel *label_11;
    QSpinBox *cannony;
    QSpinBox *cannonx;
    QSpinBox *centery;
    QSpinBox *centerx;
    QSpinBox *anchory;
    QSpinBox *anchorx;
    QSpinBox *flagy;
    QSpinBox *flagx;
    QPushButton *neighboursbutton;
    QListWidget *neighbourslist;

    void setupUi(QDockWidget *KsirkCountryDefinition)
    {
        if (KsirkCountryDefinition->objectName().isEmpty())
            KsirkCountryDefinition->setObjectName("KsirkCountryDefinition");
        KsirkCountryDefinition->resize(291, 550);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(dockWidgetContents);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(dockWidgetContents);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_2, 0, 2, 1, 1);

        label_3 = new QLabel(dockWidgetContents);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        label_4 = new QLabel(dockWidgetContents);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_4, 1, 2, 1, 1);

        label_5 = new QLabel(dockWidgetContents);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        label_6 = new QLabel(dockWidgetContents);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_6, 2, 2, 1, 1);

        label_7 = new QLabel(dockWidgetContents);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 3, 0, 1, 1);

        infantryx = new QSpinBox(dockWidgetContents);
        infantryx->setObjectName("infantryx");

        gridLayout->addWidget(infantryx, 3, 1, 1, 1);

        label_8 = new QLabel(dockWidgetContents);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_8, 3, 2, 1, 1);

        infantryy = new QSpinBox(dockWidgetContents);
        infantryy->setObjectName("infantryy");

        gridLayout->addWidget(infantryy, 3, 3, 1, 1);

        label_9 = new QLabel(dockWidgetContents);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 4, 0, 1, 1);

        cavalryx = new QSpinBox(dockWidgetContents);
        cavalryx->setObjectName("cavalryx");

        gridLayout->addWidget(cavalryx, 4, 1, 1, 1);

        label_10 = new QLabel(dockWidgetContents);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_10, 4, 2, 1, 1);

        cavalryy = new QSpinBox(dockWidgetContents);
        cavalryy->setObjectName("cavalryy");

        gridLayout->addWidget(cavalryy, 4, 3, 1, 1);

        label_12 = new QLabel(dockWidgetContents);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 5, 0, 1, 1);

        label_11 = new QLabel(dockWidgetContents);
        label_11->setObjectName("label_11");
        label_11->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_11, 5, 2, 1, 1);

        cannony = new QSpinBox(dockWidgetContents);
        cannony->setObjectName("cannony");

        gridLayout->addWidget(cannony, 5, 3, 1, 1);

        cannonx = new QSpinBox(dockWidgetContents);
        cannonx->setObjectName("cannonx");

        gridLayout->addWidget(cannonx, 5, 1, 1, 1);

        centery = new QSpinBox(dockWidgetContents);
        centery->setObjectName("centery");

        gridLayout->addWidget(centery, 2, 3, 1, 1);

        centerx = new QSpinBox(dockWidgetContents);
        centerx->setObjectName("centerx");

        gridLayout->addWidget(centerx, 2, 1, 1, 1);

        anchory = new QSpinBox(dockWidgetContents);
        anchory->setObjectName("anchory");

        gridLayout->addWidget(anchory, 1, 3, 1, 1);

        anchorx = new QSpinBox(dockWidgetContents);
        anchorx->setObjectName("anchorx");

        gridLayout->addWidget(anchorx, 1, 1, 1, 1);

        flagy = new QSpinBox(dockWidgetContents);
        flagy->setObjectName("flagy");

        gridLayout->addWidget(flagy, 0, 3, 1, 1);

        flagx = new QSpinBox(dockWidgetContents);
        flagx->setObjectName("flagx");

        gridLayout->addWidget(flagx, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        neighboursbutton = new QPushButton(dockWidgetContents);
        neighboursbutton->setObjectName("neighboursbutton");

        verticalLayout->addWidget(neighboursbutton);

        neighbourslist = new QListWidget(dockWidgetContents);
        neighbourslist->setObjectName("neighbourslist");

        verticalLayout->addWidget(neighbourslist);

        KsirkCountryDefinition->setWidget(dockWidgetContents);

        retranslateUi(KsirkCountryDefinition);

        QMetaObject::connectSlotsByName(KsirkCountryDefinition);
    } // setupUi

    void retranslateUi(QDockWidget *KsirkCountryDefinition)
    {
        KsirkCountryDefinition->setWindowTitle(tr2i18n("Country", nullptr));
        label->setText(tr2i18n("Flag:", nullptr));
        label_2->setText(tr2i18n("x", nullptr));
        label_3->setText(tr2i18n("Anchor:", nullptr));
        label_4->setText(tr2i18n("x", nullptr));
        label_5->setText(tr2i18n("Center:", nullptr));
        label_6->setText(tr2i18n("x", nullptr));
        label_7->setText(tr2i18n("Infantry:", nullptr));
#if QT_CONFIG(tooltip)
        infantryx->setToolTip(tr2i18n("Infantry's sprite top left point x-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        infantryx->setWhatsThis(tr2i18n("Infantry's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the infantry.", nullptr));
#endif // QT_CONFIG(whatsthis)
        infantryx->setProperty("text", QVariant(QString()));
        label_8->setText(tr2i18n("x", nullptr));
#if QT_CONFIG(tooltip)
        infantryy->setToolTip(tr2i18n("Infantry's sprite top left point y-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        infantryy->setWhatsThis(tr2i18n("Infantry's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the infantry by drag and drop.", nullptr));
#endif // QT_CONFIG(whatsthis)
        infantryy->setProperty("text", QVariant(QString()));
        label_9->setText(tr2i18n("Cavalry:", nullptr));
#if QT_CONFIG(tooltip)
        cavalryx->setToolTip(tr2i18n("Cavalry's sprite top left point x-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cavalryx->setWhatsThis(tr2i18n("Cavalry's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cavalry.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cavalryx->setProperty("text", QVariant(QString()));
        label_10->setText(tr2i18n("x", nullptr));
#if QT_CONFIG(tooltip)
        cavalryy->setToolTip(tr2i18n("Cavalry's sprite top left point y-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cavalryy->setWhatsThis(tr2i18n("Cavalry's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cavalry by drag and drop.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cavalryy->setProperty("text", QVariant(QString()));
        label_12->setText(tr2i18n("Cannon:", nullptr));
        label_11->setText(tr2i18n("x", nullptr));
#if QT_CONFIG(tooltip)
        cannony->setToolTip(tr2i18n("Cannon's sprite top left point y-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cannony->setWhatsThis(tr2i18n("Cannon's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cannon by drag and drop.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cannony->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        cannonx->setToolTip(tr2i18n("Cannon's sprite top left point x-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cannonx->setWhatsThis(tr2i18n("Cannon's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cannon.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cannonx->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        centery->setToolTip(tr2i18n("Point around which the country name is drawn y-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        centery->setWhatsThis(tr2i18n("Point around which the country name is drawn y-coordinate.\n"
"\n"
"Note that this point should be located inside the limits of the country on the map mask.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the country name by dragging and dropping its target icon.\n"
"", nullptr));
#endif // QT_CONFIG(whatsthis)
        centery->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        centerx->setToolTip(tr2i18n("Point around which the country name is drawn x-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        centerx->setWhatsThis(tr2i18n("Point around which the country name is drawn x-coordinate.\n"
"\n"
"Note that this point should be located inside the limits of the country on the map mask.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the country name by dragging and dropping its target icon.", nullptr));
#endif // QT_CONFIG(whatsthis)
        centerx->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        anchory->setToolTip(tr2i18n("Center of the highlighting y-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        anchory->setWhatsThis(tr2i18n("Center of the highlighting y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the highlighting by dragging and dropping its cross icon.", nullptr));
#endif // QT_CONFIG(whatsthis)
        anchory->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        anchorx->setToolTip(tr2i18n("Center of the highlighting x-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        anchorx->setWhatsThis(tr2i18n("Center of the highlighting x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the highlighting by dragging and dropping its cross icon.", nullptr));
#endif // QT_CONFIG(whatsthis)
        anchorx->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        flagy->setToolTip(tr2i18n("Flag's sprite top left point y-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        flagy->setWhatsThis(tr2i18n("Flag's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the flag by drag and drop.", nullptr));
#endif // QT_CONFIG(whatsthis)
        flagy->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        flagx->setToolTip(tr2i18n("Flag's sprite top left point x-coordinate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        flagx->setWhatsThis(tr2i18n("Flag's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the flag by drag and drop.", nullptr));
#endif // QT_CONFIG(whatsthis)
        flagx->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        neighboursbutton->setToolTip(tr2i18n("Select this country's neighbors", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        neighboursbutton->setWhatsThis(tr2i18n("Click here to select this country's neighbors.\n"
"\n"
"A list of all the world's countries will be shown and you will be able to select the countries using the mouse and the Ctrl and Shift keys.", nullptr));
#endif // QT_CONFIG(whatsthis)
        neighboursbutton->setText(tr2i18n("Neighbors:", nullptr));
#if QT_CONFIG(tooltip)
        neighbourslist->setToolTip(tr2i18n("This country's neighbors", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        neighbourslist->setWhatsThis(tr2i18n("This is the list of countries currently considered as neighbors of this country.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class KsirkCountryDefinition: public Ui_KsirkCountryDefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKCOUNTRYDEFINITION_H

