/****************************************************************************
** Meta object code from reading C++ file 'decoratedgameframe.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksirk-26.07.80/ksirk/decoratedgameframe.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decoratedgameframe.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Ksirk11ArenaActionE_t {};
} // unnamed namespace

template <> constexpr inline auto Ksirk::ArenaAction::qt_create_metaobjectdata<qt_meta_tag_ZN5Ksirk11ArenaActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ksirk::ArenaAction"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ArenaAction, qt_meta_tag_ZN5Ksirk11ArenaActionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ksirk::ArenaAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QAction::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk11ArenaActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk11ArenaActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Ksirk11ArenaActionE_t>.metaTypes,
    nullptr
} };

void Ksirk::ArenaAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ArenaAction *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Ksirk::ArenaAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::ArenaAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk11ArenaActionE_t>.strings))
        return static_cast<void*>(this);
    return QAction::qt_metacast(_clname);
}

int Ksirk::ArenaAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAction::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN5Ksirk18DecoratedGameFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto Ksirk::DecoratedGameFrame::qt_create_metaobjectdata<qt_meta_tag_ZN5Ksirk18DecoratedGameFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ksirk::DecoratedGameFrame",
        "mouseMoveEventReceived",
        "",
        "QMouseEvent*",
        "event",
        "arenaStateSignal",
        "slotMouseInput",
        "KGameIO*",
        "input",
        "QDataStream&",
        "stream",
        "mouse",
        "bool*",
        "eatevent",
        "arenaState",
        "slotDetails",
        "attackAuto"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mouseMoveEventReceived'
        QtMocHelpers::SignalData<void(QMouseEvent *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'arenaStateSignal'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotMouseInput'
        QtMocHelpers::SlotData<void(KGameIO *, QDataStream &, QMouseEvent *, bool *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 3, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'arenaState'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDetails'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'attackAuto'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecoratedGameFrame, qt_meta_tag_ZN5Ksirk18DecoratedGameFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ksirk::DecoratedGameFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk18DecoratedGameFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk18DecoratedGameFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Ksirk18DecoratedGameFrameE_t>.metaTypes,
    nullptr
} };

void Ksirk::DecoratedGameFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecoratedGameFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mouseMoveEventReceived((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 1: _t->arenaStateSignal((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->slotMouseInput((*reinterpret_cast<std::add_pointer_t<KGameIO*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDataStream&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[4]))); break;
        case 3: _t->arenaState(); break;
        case 4: _t->slotDetails(); break;
        case 5: _t->attackAuto(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGameIO* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecoratedGameFrame::*)(QMouseEvent * )>(_a, &DecoratedGameFrame::mouseMoveEventReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedGameFrame::*)(bool )>(_a, &DecoratedGameFrame::arenaStateSignal, 1))
            return;
    }
}

const QMetaObject *Ksirk::DecoratedGameFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::DecoratedGameFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk18DecoratedGameFrameE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int Ksirk::DecoratedGameFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Ksirk::DecoratedGameFrame::mouseMoveEventReceived(QMouseEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ksirk::DecoratedGameFrame::arenaStateSignal(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
