/********************************************************************************
** Form generated from reading UI file 'joingame.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JOINGAME_H
#define UI_JOINGAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_JoinGameDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label;
    KLineEdit *hostEdit;
    QLabel *label_2;
    KLineEdit *portEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *JoinGameDialog)
    {
        if (JoinGameDialog->objectName().isEmpty())
            JoinGameDialog->setObjectName("JoinGameDialog");
        JoinGameDialog->resize(525, 372);
        verticalLayout = new QVBoxLayout(JoinGameDialog);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(JoinGameDialog);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        hostEdit = new KLineEdit(groupBox);
        hostEdit->setObjectName("hostEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, hostEdit);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        portEdit = new KLineEdit(groupBox);
        portEdit->setObjectName("portEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, portEdit);


        verticalLayout->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(JoinGameDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(JoinGameDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, JoinGameDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, JoinGameDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(JoinGameDialog);
    } // setupUi

    void retranslateUi(QDialog *JoinGameDialog)
    {
        JoinGameDialog->setWindowTitle(tr2i18n("Join Network Game Configuration", nullptr));
        groupBox->setTitle(tr2i18n("Network Configuration", nullptr));
        label->setText(tr2i18n("Host:", nullptr));
        label_2->setText(tr2i18n("Port:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class JoinGameDialog: public Ui_JoinGameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JOINGAME_H

