/********************************************************************************
** Form generated from reading UI file 'ksirkspritesdefinition.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKSPRITESDEFINITION_H
#define UI_KSIRKSPRITESDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KsirkSpritesDefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_26;
    QLineEdit *widthDiffLineEdit;
    QTabWidget *ktabwidget;
    QWidget *flagTab;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout_5;
    QLabel *label;
    QSpinBox *flagw;
    QLabel *label_2;
    QSpinBox *flagh;
    QLabel *label_3;
    QSpinBox *flagf;
    QLabel *label_4;
    QSpinBox *flagv;
    QSpacerItem *verticalSpacer_6;
    QWidget *infantryTab;
    QGridLayout *gridLayout_7;
    QLabel *label_5;
    QSpinBox *infantryw;
    QLabel *label_6;
    QSpinBox *infantryh;
    QLabel *label_8;
    QSpinBox *infantryf;
    QLabel *label_7;
    QSpinBox *infantryv;
    QSpacerItem *verticalSpacer_5;
    QWidget *cavalryTab;
    QGridLayout *gridLayout_3;
    QLabel *label_10;
    QSpinBox *cavalryw;
    QLabel *label_9;
    QSpinBox *cavalryh;
    QLabel *label_11;
    QSpinBox *cavalryf;
    QLabel *label_12;
    QSpinBox *cavalryv;
    QSpacerItem *verticalSpacer_4;
    QWidget *cannonTab;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout_4;
    QLabel *label_14;
    QSpinBox *cannonw;
    QLabel *label_13;
    QSpinBox *cannonh;
    QLabel *label_15;
    QSpinBox *cannonf;
    QLabel *label_16;
    QSpinBox *cannonv;
    QSpacerItem *verticalSpacer_3;
    QWidget *firingTab;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_18;
    QSpinBox *firingw;
    QLabel *label_17;
    QSpinBox *firingh;
    QLabel *label_19;
    QSpinBox *firingf;
    QLabel *label_20;
    QSpinBox *firingv;
    QSpacerItem *verticalSpacer;
    QWidget *explodingTab;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_2;
    QLabel *label_22;
    QSpinBox *explodingw;
    QLabel *label_21;
    QSpinBox *explodingh;
    QLabel *label_23;
    QSpinBox *explodingf;
    QLabel *label_24;
    QSpinBox *explodingv;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QDockWidget *KsirkSpritesDefinition)
    {
        if (KsirkSpritesDefinition->objectName().isEmpty())
            KsirkSpritesDefinition->setObjectName("KsirkSpritesDefinition");
        KsirkSpritesDefinition->resize(293, 523);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout_5 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_5->setObjectName("verticalLayout_5");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_26 = new QLabel(dockWidgetContents);
        label_26->setObjectName("label_26");
        label_26->setEnabled(true);
        label_26->setTextInteractionFlags(Qt::NoTextInteraction);

        horizontalLayout_4->addWidget(label_26);

        widthDiffLineEdit = new QLineEdit(dockWidgetContents);
        widthDiffLineEdit->setObjectName("widthDiffLineEdit");

        horizontalLayout_4->addWidget(widthDiffLineEdit);


        verticalLayout_5->addLayout(horizontalLayout_4);

        ktabwidget = new QTabWidget(dockWidgetContents);
        ktabwidget->setObjectName("ktabwidget");
        ktabwidget->setTabPosition(QTabWidget::West);
        flagTab = new QWidget();
        flagTab->setObjectName("flagTab");
        verticalLayout_4 = new QVBoxLayout(flagTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        label = new QLabel(flagTab);
        label->setObjectName("label");

        gridLayout_5->addWidget(label, 0, 0, 1, 1);

        flagw = new QSpinBox(flagTab);
        flagw->setObjectName("flagw");

        gridLayout_5->addWidget(flagw, 0, 1, 1, 1);

        label_2 = new QLabel(flagTab);
        label_2->setObjectName("label_2");

        gridLayout_5->addWidget(label_2, 1, 0, 1, 1);

        flagh = new QSpinBox(flagTab);
        flagh->setObjectName("flagh");

        gridLayout_5->addWidget(flagh, 1, 1, 1, 1);

        label_3 = new QLabel(flagTab);
        label_3->setObjectName("label_3");

        gridLayout_5->addWidget(label_3, 2, 0, 1, 1);

        flagf = new QSpinBox(flagTab);
        flagf->setObjectName("flagf");

        gridLayout_5->addWidget(flagf, 2, 1, 1, 1);

        label_4 = new QLabel(flagTab);
        label_4->setObjectName("label_4");

        gridLayout_5->addWidget(label_4, 3, 0, 1, 1);

        flagv = new QSpinBox(flagTab);
        flagv->setObjectName("flagv");

        gridLayout_5->addWidget(flagv, 3, 1, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_6, 4, 0, 1, 1);


        verticalLayout_4->addLayout(gridLayout_5);

        ktabwidget->addTab(flagTab, QString());
        infantryTab = new QWidget();
        infantryTab->setObjectName("infantryTab");
        gridLayout_7 = new QGridLayout(infantryTab);
        gridLayout_7->setObjectName("gridLayout_7");
        label_5 = new QLabel(infantryTab);
        label_5->setObjectName("label_5");

        gridLayout_7->addWidget(label_5, 0, 0, 1, 1);

        infantryw = new QSpinBox(infantryTab);
        infantryw->setObjectName("infantryw");

        gridLayout_7->addWidget(infantryw, 0, 1, 1, 1);

        label_6 = new QLabel(infantryTab);
        label_6->setObjectName("label_6");

        gridLayout_7->addWidget(label_6, 1, 0, 1, 1);

        infantryh = new QSpinBox(infantryTab);
        infantryh->setObjectName("infantryh");

        gridLayout_7->addWidget(infantryh, 1, 1, 1, 1);

        label_8 = new QLabel(infantryTab);
        label_8->setObjectName("label_8");

        gridLayout_7->addWidget(label_8, 2, 0, 1, 1);

        infantryf = new QSpinBox(infantryTab);
        infantryf->setObjectName("infantryf");

        gridLayout_7->addWidget(infantryf, 2, 1, 1, 1);

        label_7 = new QLabel(infantryTab);
        label_7->setObjectName("label_7");

        gridLayout_7->addWidget(label_7, 3, 0, 1, 1);

        infantryv = new QSpinBox(infantryTab);
        infantryv->setObjectName("infantryv");

        gridLayout_7->addWidget(infantryv, 3, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_7->addItem(verticalSpacer_5, 4, 0, 1, 1);

        ktabwidget->addTab(infantryTab, QString());
        cavalryTab = new QWidget();
        cavalryTab->setObjectName("cavalryTab");
        gridLayout_3 = new QGridLayout(cavalryTab);
        gridLayout_3->setObjectName("gridLayout_3");
        label_10 = new QLabel(cavalryTab);
        label_10->setObjectName("label_10");

        gridLayout_3->addWidget(label_10, 0, 0, 1, 1);

        cavalryw = new QSpinBox(cavalryTab);
        cavalryw->setObjectName("cavalryw");

        gridLayout_3->addWidget(cavalryw, 0, 1, 1, 1);

        label_9 = new QLabel(cavalryTab);
        label_9->setObjectName("label_9");

        gridLayout_3->addWidget(label_9, 1, 0, 1, 1);

        cavalryh = new QSpinBox(cavalryTab);
        cavalryh->setObjectName("cavalryh");

        gridLayout_3->addWidget(cavalryh, 1, 1, 1, 1);

        label_11 = new QLabel(cavalryTab);
        label_11->setObjectName("label_11");

        gridLayout_3->addWidget(label_11, 2, 0, 1, 1);

        cavalryf = new QSpinBox(cavalryTab);
        cavalryf->setObjectName("cavalryf");

        gridLayout_3->addWidget(cavalryf, 2, 1, 1, 1);

        label_12 = new QLabel(cavalryTab);
        label_12->setObjectName("label_12");

        gridLayout_3->addWidget(label_12, 3, 0, 1, 1);

        cavalryv = new QSpinBox(cavalryTab);
        cavalryv->setObjectName("cavalryv");

        gridLayout_3->addWidget(cavalryv, 3, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_4, 4, 0, 1, 1);

        ktabwidget->addTab(cavalryTab, QString());
        cannonTab = new QWidget();
        cannonTab->setObjectName("cannonTab");
        verticalLayout_3 = new QVBoxLayout(cannonTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        label_14 = new QLabel(cannonTab);
        label_14->setObjectName("label_14");

        gridLayout_4->addWidget(label_14, 0, 0, 1, 1);

        cannonw = new QSpinBox(cannonTab);
        cannonw->setObjectName("cannonw");

        gridLayout_4->addWidget(cannonw, 0, 1, 1, 1);

        label_13 = new QLabel(cannonTab);
        label_13->setObjectName("label_13");

        gridLayout_4->addWidget(label_13, 1, 0, 1, 1);

        cannonh = new QSpinBox(cannonTab);
        cannonh->setObjectName("cannonh");

        gridLayout_4->addWidget(cannonh, 1, 1, 1, 1);

        label_15 = new QLabel(cannonTab);
        label_15->setObjectName("label_15");

        gridLayout_4->addWidget(label_15, 2, 0, 1, 1);

        cannonf = new QSpinBox(cannonTab);
        cannonf->setObjectName("cannonf");

        gridLayout_4->addWidget(cannonf, 2, 1, 1, 1);

        label_16 = new QLabel(cannonTab);
        label_16->setObjectName("label_16");

        gridLayout_4->addWidget(label_16, 3, 0, 1, 1);

        cannonv = new QSpinBox(cannonTab);
        cannonv->setObjectName("cannonv");

        gridLayout_4->addWidget(cannonv, 3, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_3, 4, 0, 1, 1);


        verticalLayout_3->addLayout(gridLayout_4);

        ktabwidget->addTab(cannonTab, QString());
        firingTab = new QWidget();
        firingTab->setObjectName("firingTab");
        verticalLayout = new QVBoxLayout(firingTab);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_18 = new QLabel(firingTab);
        label_18->setObjectName("label_18");

        gridLayout->addWidget(label_18, 0, 0, 1, 1);

        firingw = new QSpinBox(firingTab);
        firingw->setObjectName("firingw");

        gridLayout->addWidget(firingw, 0, 1, 1, 1);

        label_17 = new QLabel(firingTab);
        label_17->setObjectName("label_17");

        gridLayout->addWidget(label_17, 1, 0, 1, 1);

        firingh = new QSpinBox(firingTab);
        firingh->setObjectName("firingh");

        gridLayout->addWidget(firingh, 1, 1, 1, 1);

        label_19 = new QLabel(firingTab);
        label_19->setObjectName("label_19");

        gridLayout->addWidget(label_19, 2, 0, 1, 1);

        firingf = new QSpinBox(firingTab);
        firingf->setObjectName("firingf");

        gridLayout->addWidget(firingf, 2, 1, 1, 1);

        label_20 = new QLabel(firingTab);
        label_20->setObjectName("label_20");

        gridLayout->addWidget(label_20, 3, 0, 1, 1);

        firingv = new QSpinBox(firingTab);
        firingv->setObjectName("firingv");

        gridLayout->addWidget(firingv, 3, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        ktabwidget->addTab(firingTab, QString());
        explodingTab = new QWidget();
        explodingTab->setObjectName("explodingTab");
        verticalLayout_2 = new QVBoxLayout(explodingTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label_22 = new QLabel(explodingTab);
        label_22->setObjectName("label_22");

        gridLayout_2->addWidget(label_22, 0, 0, 1, 1);

        explodingw = new QSpinBox(explodingTab);
        explodingw->setObjectName("explodingw");

        gridLayout_2->addWidget(explodingw, 0, 1, 1, 1);

        label_21 = new QLabel(explodingTab);
        label_21->setObjectName("label_21");

        gridLayout_2->addWidget(label_21, 1, 0, 1, 1);

        explodingh = new QSpinBox(explodingTab);
        explodingh->setObjectName("explodingh");

        gridLayout_2->addWidget(explodingh, 1, 1, 1, 1);

        label_23 = new QLabel(explodingTab);
        label_23->setObjectName("label_23");

        gridLayout_2->addWidget(label_23, 2, 0, 1, 1);

        explodingf = new QSpinBox(explodingTab);
        explodingf->setObjectName("explodingf");

        gridLayout_2->addWidget(explodingf, 2, 1, 1, 1);

        label_24 = new QLabel(explodingTab);
        label_24->setObjectName("label_24");

        gridLayout_2->addWidget(label_24, 3, 0, 1, 1);

        explodingv = new QSpinBox(explodingTab);
        explodingv->setObjectName("explodingv");

        gridLayout_2->addWidget(explodingv, 3, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 4, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        ktabwidget->addTab(explodingTab, QString());

        verticalLayout_5->addWidget(ktabwidget);

        KsirkSpritesDefinition->setWidget(dockWidgetContents);

        retranslateUi(KsirkSpritesDefinition);

        ktabwidget->setCurrentIndex(5);


        QMetaObject::connectSlotsByName(KsirkSpritesDefinition);
    } // setupUi

    void retranslateUi(QDockWidget *KsirkSpritesDefinition)
    {
        KsirkSpritesDefinition->setWindowTitle(tr2i18n("Sprites", nullptr));
#if QT_CONFIG(whatsthis)
        label_26->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        label_26->setText(tr2i18n("Width between fighter\n"
"and flag:", nullptr));
#if QT_CONFIG(tooltip)
        widthDiffLineEdit->setToolTip(tr2i18n("Empty space size between fighting cannon and flag", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        widthDiffLineEdit->setWhatsThis(tr2i18n("Empty space size between fighting cannon and flag.\n"
"\n"
"During a battle, firing (end exploding) cannons of each player are placed in both sides of the defender country flag. This parameter is the number of pixels between the flag and each cannon, measured relatively to the map base size as set in the main skin definition panel.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        ktabwidget->setToolTip(tr2i18n("Data about all sprites", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        flagTab->setToolTip(tr2i18n("Data about the flag sprite", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        flagw->setToolTip(tr2i18n("Flag individual frame width", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        flagw->setWhatsThis(tr2i18n("<p>Flag individual frame width.</p><p>The pool <i>flag</i> element will be rendered on a pixmap of width: <i>Width</i> * N<i>number of frames</i> and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        flagh->setToolTip(tr2i18n("Flag individual frame height", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        flagh->setWhatsThis(tr2i18n("Flag individual frame height.\n"
"\n"
"The pool flag element will be rendered on a pixmap of height: (Height * Number of versions) and then split into individual frames.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Nb frames:", nullptr));
#if QT_CONFIG(tooltip)
        flagf->setToolTip(tr2i18n("Number of individual flag frames", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        flagf->setWhatsThis(tr2i18n("<p>Number of individual flag frames.</p><p>The pool <i>flag</i> element will be rendered on a pixmap of width: (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_4->setText(tr2i18n("Nb versions:", nullptr));
#if QT_CONFIG(tooltip)
        flagv->setToolTip(tr2i18n("Number of flag versions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        flagv->setWhatsThis(tr2i18n("Number of flag versions.\n"
"\n"
"The pool flag element will be rendered on a pixmap of height: (Height * Number of versions) and then split into individual frames.\n"
"\n"
"Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from the front and the last one from the back. However, not all sprites need all versions.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ktabwidget->setTabText(ktabwidget->indexOf(flagTab), tr2i18n("Flag", nullptr));
#if QT_CONFIG(tooltip)
        infantryTab->setToolTip(tr2i18n("Data about the infantry sprite", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        infantryw->setToolTip(tr2i18n("Infantry individual frame width", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        infantryw->setWhatsThis(tr2i18n("<p>Infantry individual frame width.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of width: <i>Width</i> * <i>number of frames</i> and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_6->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        infantryh->setToolTip(tr2i18n("Infantry individual frame height", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        infantryh->setWhatsThis(tr2i18n("<p>Infantry individual frame height.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of height: <i>Height</i> * <i>Number of versions</i> and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_8->setText(tr2i18n("Nb frames:", nullptr));
#if QT_CONFIG(tooltip)
        infantryf->setToolTip(tr2i18n("Number of individual infantry frames", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        infantryf->setWhatsThis(tr2i18n("<p>Infantry number of individual frames.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of width: (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_7->setText(tr2i18n("Nb versions:", nullptr));
#if QT_CONFIG(tooltip)
        infantryv->setToolTip(tr2i18n("Number of infantry versions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        infantryv->setWhatsThis(tr2i18n("<p>Number of infantry versions.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of height: (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        ktabwidget->setTabText(ktabwidget->indexOf(infantryTab), tr2i18n("Infantry", nullptr));
#if QT_CONFIG(tooltip)
        cavalryTab->setToolTip(tr2i18n("Data about the cavalry sprite", nullptr));
#endif // QT_CONFIG(tooltip)
        label_10->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        cavalryw->setToolTip(tr2i18n("Individual cavalry frame width", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cavalryw->setWhatsThis(tr2i18n("<p>Individual cavalry frame width.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_9->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        cavalryh->setToolTip(tr2i18n("Individual cavalry frame height", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cavalryh->setWhatsThis(tr2i18n("<p>Individual cavalry frame height.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_11->setText(tr2i18n("Nb frames:", nullptr));
#if QT_CONFIG(tooltip)
        cavalryf->setToolTip(tr2i18n("Number of individual cavalry frames", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cavalryf->setWhatsThis(tr2i18n("<p>Number of individual cavalry frames.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of width: (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_12->setText(tr2i18n("Nb versions:", nullptr));
#if QT_CONFIG(tooltip)
        cavalryv->setToolTip(tr2i18n("Number of cavalry versions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cavalryv->setWhatsThis(tr2i18n("<p>Number of cavalry versions.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        ktabwidget->setTabText(ktabwidget->indexOf(cavalryTab), tr2i18n("Cavalry", nullptr));
#if QT_CONFIG(tooltip)
        cannonTab->setToolTip(tr2i18n("Data about the cannon sprite", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        cannonw->setToolTip(tr2i18n("Cannon individual frame width", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cannonw->setWhatsThis(tr2i18n("<p>Cannon individual frame width.</p><p>The pool <i>cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_13->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        cannonh->setToolTip(tr2i18n("Individual cannon frame height", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cannonh->setWhatsThis(tr2i18n("<p>Individual cannon frame height.</p><p>The pool <i>cannon<i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_15->setText(tr2i18n("Nb frames:", nullptr));
#if QT_CONFIG(tooltip)
        cannonf->setToolTip(tr2i18n("Number of individual cannon frames", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cannonf->setWhatsThis(tr2i18n("<p>Number of individual cannon frames.</p><p>The pool <i>cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_16->setText(tr2i18n("Nb versions:", nullptr));
#if QT_CONFIG(tooltip)
        cannonv->setToolTip(tr2i18n("Number of cannon versions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cannonv->setWhatsThis(tr2i18n("<p>Number of cannon versions.</p><p>The pool <i>cannon</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        ktabwidget->setTabText(ktabwidget->indexOf(cannonTab), tr2i18n("Cannon", nullptr));
#if QT_CONFIG(tooltip)
        firingTab->setToolTip(tr2i18n("Data about the firing sprite", nullptr));
#endif // QT_CONFIG(tooltip)
        label_18->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        firingw->setToolTip(tr2i18n("Firing cannon individual frame width", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        firingw->setWhatsThis(tr2i18n("<p>Firing cannon individual frame width.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_17->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        firingh->setToolTip(tr2i18n("Firing cannon individual frame height", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        firingh->setWhatsThis(tr2i18n("<p>Firing cannon individual frame height.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_19->setText(tr2i18n("Nb frames:", nullptr));
#if QT_CONFIG(tooltip)
        firingf->setToolTip(tr2i18n("Number of individual firing cannon frames", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        firingf->setWhatsThis(tr2i18n("<p>Number of individual firing cannon frames.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_20->setText(tr2i18n("Nb versions:", nullptr));
#if QT_CONFIG(tooltip)
        firingv->setToolTip(tr2i18n("Number of firing cannon versions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        firingv->setWhatsThis(tr2i18n("<p>Number of firing cannon versions.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        ktabwidget->setTabText(ktabwidget->indexOf(firingTab), tr2i18n("Firing", nullptr));
#if QT_CONFIG(tooltip)
        explodingTab->setToolTip(tr2i18n("Data about the exploding sprite", nullptr));
#endif // QT_CONFIG(tooltip)
        label_22->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        explodingw->setToolTip(tr2i18n("Exploding cannon individual frame width", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        explodingw->setWhatsThis(tr2i18n("<p>Exploding cannon individual frame width.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_21->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        explodingh->setToolTip(tr2i18n("Exploding cannon individual frame height", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        explodingh->setWhatsThis(tr2i18n("<p>Exploding cannon individual frame height.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_23->setText(tr2i18n("Nb frames:", nullptr));
#if QT_CONFIG(tooltip)
        explodingf->setToolTip(tr2i18n("Number of individual exploding cannon frames", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        explodingf->setWhatsThis(tr2i18n("<p>Number of individual exploding cannon frames.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_24->setText(tr2i18n("Nb versions:", nullptr));
#if QT_CONFIG(tooltip)
        explodingv->setToolTip(tr2i18n("Number of exploding cannon versions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        explodingv->setWhatsThis(tr2i18n("<p>Number of exploding cannon versions.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        ktabwidget->setTabText(ktabwidget->indexOf(explodingTab), tr2i18n("Exploding", nullptr));
    } // retranslateUi

};

namespace Ui {
    class KsirkSpritesDefinition: public Ui_KsirkSpritesDefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKSPRITESDEFINITION_H

