/********************************************************************************
** Form generated from reading UI file 'qplayersetupdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QPLAYERSETUPDIALOG_H
#define UI_QPLAYERSETUPDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpassworddialog.h"

QT_BEGIN_NAMESPACE

class Ui_QPlayerSetupWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *TextLabel1;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *nameLineEdit;
    QComboBox *nationCombo;
    QLabel *messageLabel;
    QHBoxLayout *horizontalLayout;
    QLabel *passwordLabel;
    QLineEdit *passwordEdit;
    QCheckBox *isComputerCheckBox;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *previousButton;
    QPushButton *nextButton;

    void setupUi(QWidget *QPlayerSetupWidget)
    {
        if (QPlayerSetupWidget->objectName().isEmpty())
            QPlayerSetupWidget->setObjectName("QPlayerSetupWidget");
        QPlayerSetupWidget->resize(560, 393);
        verticalLayout = new QVBoxLayout(QPlayerSetupWidget);
        verticalLayout->setObjectName("verticalLayout");
        TextLabel1 = new QLabel(QPlayerSetupWidget);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setFrameShape(QFrame::NoFrame);
        TextLabel1->setText(QString::fromUtf8("Player number X, please enter your name and choose your nation:"));
        TextLabel1->setWordWrap(true);

        verticalLayout->addWidget(TextLabel1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        nameLineEdit = new QLineEdit(QPlayerSetupWidget);
        nameLineEdit->setObjectName("nameLineEdit");
        nameLineEdit->setMaxLength(30);
        nameLineEdit->setAlignment(Qt::AlignLeading);

        horizontalLayout_2->addWidget(nameLineEdit);

        nationCombo = new QComboBox(QPlayerSetupWidget);
        nationCombo->setObjectName("nationCombo");
        nationCombo->setDuplicatesEnabled(false);

        horizontalLayout_2->addWidget(nationCombo);


        verticalLayout->addLayout(horizontalLayout_2);

        messageLabel = new QLabel(QPlayerSetupWidget);
        messageLabel->setObjectName("messageLabel");
        messageLabel->setEnabled(true);
        messageLabel->setText(QString::fromUtf8("TextLabel"));

        verticalLayout->addWidget(messageLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        passwordLabel = new QLabel(QPlayerSetupWidget);
        passwordLabel->setObjectName("passwordLabel");
        passwordLabel->setWordWrap(false);

        horizontalLayout->addWidget(passwordLabel);

        passwordEdit = new QLineEdit(QPlayerSetupWidget);
        passwordEdit->setObjectName("passwordEdit");
        passwordEdit->setEnabled(true);
        passwordEdit->setMaxLength(8);
        passwordEdit->setEchoMode(QLineEdit::Password);

        horizontalLayout->addWidget(passwordEdit);


        verticalLayout->addLayout(horizontalLayout);

        isComputerCheckBox = new QCheckBox(QPlayerSetupWidget);
        isComputerCheckBox->setObjectName("isComputerCheckBox");

        verticalLayout->addWidget(isComputerCheckBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        cancelButton = new QPushButton(QPlayerSetupWidget);
        cancelButton->setObjectName("cancelButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-cancel")));
        cancelButton->setIcon(icon);

        horizontalLayout_3->addWidget(cancelButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        previousButton = new QPushButton(QPlayerSetupWidget);
        previousButton->setObjectName("previousButton");

        horizontalLayout_3->addWidget(previousButton);

        nextButton = new QPushButton(QPlayerSetupWidget);
        nextButton->setObjectName("nextButton");

        horizontalLayout_3->addWidget(nextButton);


        verticalLayout->addLayout(horizontalLayout_3);

#if QT_CONFIG(shortcut)
        TextLabel1->setBuddy(nameLineEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(nameLineEdit, nationCombo);
        QWidget::setTabOrder(nationCombo, isComputerCheckBox);

        retranslateUi(QPlayerSetupWidget);

        QMetaObject::connectSlotsByName(QPlayerSetupWidget);
    } // setupUi

    void retranslateUi(QWidget *QPlayerSetupWidget)
    {
        nameLineEdit->setText(QString());
#if QT_CONFIG(tooltip)
        nationCombo->setToolTip(tr2i18n("Choose your nation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        nationCombo->setWhatsThis(tr2i18n("A combo box that lists currently available nations.\n"
"Choose one of them. It will be your nation during the game", nullptr));
#endif // QT_CONFIG(whatsthis)
        passwordLabel->setText(tr2i18n("Enter your password:", nullptr));
        isComputerCheckBox->setText(tr2i18n("Pla&yer is computer", nullptr));
        cancelButton->setText(tr2i18n("Cancel", nullptr));
        previousButton->setText(tr2i18n("Previous", nullptr));
        nextButton->setText(tr2i18n("Next", nullptr));
        (void)QPlayerSetupWidget;
    } // retranslateUi

};

namespace Ui {
    class QPlayerSetupWidget: public Ui_QPlayerSetupWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QPLAYERSETUPDIALOG_H

