/********************************************************************************
** Form generated from reading UI file 'ksirkskineditorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKSKINEDITORWIDGET_H
#define UI_KSIRKSKINEDITORWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skinEditor
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QScrollArea *buttonsScrollArea;
    QWidget *scrollAreaWidgetContents;
    QScrollArea *mapScrollArea;
    QWidget *scrollAreaWidgetContents_2;

    void setupUi(QFrame *skinEditor)
    {
        if (skinEditor->objectName().isEmpty())
            skinEditor->setObjectName("skinEditor");
        skinEditor->resize(683, 530);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skinEditor->sizePolicy().hasHeightForWidth());
        skinEditor->setSizePolicy(sizePolicy);
        skinEditor->setFrameShape(QFrame::StyledPanel);
        skinEditor->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(skinEditor);
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        buttonsScrollArea = new QScrollArea(skinEditor);
        buttonsScrollArea->setObjectName("buttonsScrollArea");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buttonsScrollArea->sizePolicy().hasHeightForWidth());
        buttonsScrollArea->setSizePolicy(sizePolicy1);
        buttonsScrollArea->setMinimumSize(QSize(0, 50));
        buttonsScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 661, 54));
        buttonsScrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(buttonsScrollArea);

        mapScrollArea = new QScrollArea(skinEditor);
        mapScrollArea->setObjectName("mapScrollArea");
        mapScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 661, 444));
        mapScrollArea->setWidget(scrollAreaWidgetContents_2);

        verticalLayout->addWidget(mapScrollArea);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(skinEditor);

        QMetaObject::connectSlotsByName(skinEditor);
    } // setupUi

    void retranslateUi(QFrame *skinEditor)
    {
#if QT_CONFIG(tooltip)
        buttonsScrollArea->setToolTip(tr2i18n("Sprite placement buttons", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        buttonsScrollArea->setWhatsThis(tr2i18n("Use the buttons here to do the initial placement of the corresponding sprite for the currently selected country. The buttons are available only if the sprite is not already placed. ", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        mapScrollArea->setToolTip(tr2i18n("Map with sprites", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mapScrollArea->setWhatsThis(tr2i18n("Shows the map of the skin with all already placed sprites, the country names, and the highlighting anchors.\n"
"\n"
"Drag and drop the sprites, the country names, and the highlighting anchors to change their place.", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)skinEditor;
    } // retranslateUi

};

namespace Ui {
    class skinEditor: public Ui_skinEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKSKINEDITORWIDGET_H

