/********************************************************************************
** Form generated from reading UI file 'preferences.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCES_H
#define UI_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KsirkSkinEditorPreferencesWidget
{
public:
    QGridLayout *gridLayout;

    void setupUi(QWidget *KsirkSkinEditorPreferencesWidget)
    {
        if (KsirkSkinEditorPreferencesWidget->objectName().isEmpty())
            KsirkSkinEditorPreferencesWidget->setObjectName("KsirkSkinEditorPreferencesWidget");
        KsirkSkinEditorPreferencesWidget->resize(533, 294);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(15);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KsirkSkinEditorPreferencesWidget->sizePolicy().hasHeightForWidth());
        KsirkSkinEditorPreferencesWidget->setSizePolicy(sizePolicy);
        KsirkSkinEditorPreferencesWidget->setMinimumSize(QSize(100, 100));
        gridLayout = new QGridLayout(KsirkSkinEditorPreferencesWidget);
        gridLayout->setObjectName("gridLayout");

        retranslateUi(KsirkSkinEditorPreferencesWidget);

        QMetaObject::connectSlotsByName(KsirkSkinEditorPreferencesWidget);
    } // setupUi

    void retranslateUi(QWidget *KsirkSkinEditorPreferencesWidget)
    {
        (void)KsirkSkinEditorPreferencesWidget;
    } // retranslateUi

};

namespace Ui {
    class KsirkSkinEditorPreferencesWidget: public Ui_KsirkSkinEditorPreferencesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCES_H

