/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksirk-26.07.80/ksirkskineditor/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KsirkSkinEditor10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KsirkSkinEditor::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN15KsirkSkinEditor10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KsirkSkinEditor::MainWindow",
        "slotShowAboutApplication",
        "",
        "optionsConfigure",
        "slotFlagButtonClicked",
        "slotInfantryButtonClicked",
        "slotCavalryButtonClicked",
        "slotCannonButtonClicked",
        "slotAnchorButtonClicked",
        "slotCenterButtonClicked",
        "slotPosition",
        "QPointF",
        "slotPressPosition",
        "slotCountrySelected",
        "QListWidgetItem*",
        "item",
        "slotContinentSelected",
        "slotItemPressed",
        "QGraphicsItem*",
        "slotItemPlaced",
        "slotOpenSkin",
        "slotSaveSkin",
        "slotURLSelected",
        "QUrl",
        "slotSkinNameEdited",
        "slotSkinWidthEdited",
        "slotSkinHeightEdited",
        "slotSkinDescriptionEdited",
        "slotSkinWidthDiffEdited",
        "slotNewCountry",
        "slotDeleteCountry",
        "slotNeighbours",
        "slotSkinPartTabChanged",
        "index",
        "slotContinentCountries",
        "slotContinentBonusEdited",
        "slotFlagWidthChanged",
        "slotFlagHeightChanged",
        "slotFlagFramesChanged",
        "slotFlagVersionsChanged",
        "slotInfantryWidthChanged",
        "slotInfantryHeightChanged",
        "slotInfantryFramesChanged",
        "slotInfantryVersionsChanged",
        "slotCavalryWidthChanged",
        "slotCavalryHeightChanged",
        "slotCavalryFramesChanged",
        "slotCavalryVersionsChanged",
        "slotCannonWidthChanged",
        "slotCannonHeightChanged",
        "slotCannonFramesChanged",
        "slotCannonVersionsChanged",
        "slotFiringWidthChanged",
        "slotFiringHeightChanged",
        "slotFiringFramesChanged",
        "slotFiringVersionsChanged",
        "slotExplodingWidthChanged",
        "slotExplodingHeightChanged",
        "slotExplodingFramesChanged",
        "slotExplodingVersionsChanged",
        "slotNewContinent",
        "slotDeleteContinent",
        "slotGoalSelected",
        "slotGoalTypeWorldClicked",
        "slotGoalTypePlayerClicked",
        "slotGoalTypeCountriesClicked",
        "slotGoalTypeContinentsClicked",
        "slotGoalDescriptionEdited",
        "slotGoalNbCountriesChanged",
        "slotGoalNbArmiesByCountryChanged",
        "slotGoalAnyContinentChanged",
        "slotGoalContinents",
        "slotNewGoal",
        "slotDeleteGoal",
        "slotNationalitySelected",
        "slotNationalityNameEdited",
        "slotNationalityLeaderNameEdited",
        "slotNationalityFlagEdited",
        "slotNewNationality",
        "slotDeleteNationality",
        "slotFontSelected",
        "QFont",
        "font",
        "slotFgSelected",
        "QColor",
        "color",
        "slotBgColorSelected",
        "slotReleasePosition",
        "slotFLagxValueChanged",
        "slotFLagyValueChanged",
        "v",
        "slotCenterxValueChanged",
        "slotCenteryValueChanged",
        "slotAnchorxValueChanged",
        "slotAnchoryValueChanged",
        "slotCavalryxValueChanged",
        "slotCavalryyValueChanged",
        "slotCannonxValueChanged",
        "slotCannonyValueChanged",
        "slotInfantryxValueChanged",
        "slotInfantryyValueChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotShowAboutApplication'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'optionsConfigure'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFlagButtonClicked'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInfantryButtonClicked'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCavalryButtonClicked'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCannonButtonClicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAnchorButtonClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCenterButtonClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPosition'
        QtMocHelpers::SlotData<void(const QPointF &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotPressPosition'
        QtMocHelpers::SlotData<void(const QPointF &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotCountrySelected'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotContinentSelected'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotItemPressed'
        QtMocHelpers::SlotData<void(QGraphicsItem *, const QPointF &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 }, { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotItemPlaced'
        QtMocHelpers::SlotData<void(QGraphicsItem *, const QPointF &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 }, { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotOpenSkin'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveSkin'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotURLSelected'
        QtMocHelpers::SlotData<void(const QUrl &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'slotSkinNameEdited'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSkinWidthEdited'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotSkinHeightEdited'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotSkinDescriptionEdited'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSkinWidthDiffEdited'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewCountry'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteCountry'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNeighbours'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSkinPartTabChanged'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'slotContinentCountries'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotContinentBonusEdited'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFlagWidthChanged'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFlagHeightChanged'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFlagFramesChanged'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFlagVersionsChanged'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotInfantryWidthChanged'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotInfantryHeightChanged'
        QtMocHelpers::SlotData<void(int)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotInfantryFramesChanged'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotInfantryVersionsChanged'
        QtMocHelpers::SlotData<void(int)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCavalryWidthChanged'
        QtMocHelpers::SlotData<void(int)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCavalryHeightChanged'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCavalryFramesChanged'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCavalryVersionsChanged'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCannonWidthChanged'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCannonHeightChanged'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCannonFramesChanged'
        QtMocHelpers::SlotData<void(int)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCannonVersionsChanged'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFiringWidthChanged'
        QtMocHelpers::SlotData<void(int)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFiringHeightChanged'
        QtMocHelpers::SlotData<void(int)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFiringFramesChanged'
        QtMocHelpers::SlotData<void(int)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFiringVersionsChanged'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotExplodingWidthChanged'
        QtMocHelpers::SlotData<void(int)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotExplodingHeightChanged'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotExplodingFramesChanged'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotExplodingVersionsChanged'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotNewContinent'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteContinent'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoalSelected'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotGoalTypeWorldClicked'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoalTypePlayerClicked'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoalTypeCountriesClicked'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoalTypeContinentsClicked'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoalDescriptionEdited'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoalNbCountriesChanged'
        QtMocHelpers::SlotData<void(int)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotGoalNbArmiesByCountryChanged'
        QtMocHelpers::SlotData<void(int)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotGoalAnyContinentChanged'
        QtMocHelpers::SlotData<void(bool)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotGoalContinents'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewGoal'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteGoal'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNationalitySelected'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotNationalityNameEdited'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNationalityLeaderNameEdited'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNationalityFlagEdited'
        QtMocHelpers::SlotData<void(int)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotNewNationality'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteNationality'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFontSelected'
        QtMocHelpers::SlotData<void(const QFont &)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 82 },
        }}),
        // Slot 'slotFgSelected'
        QtMocHelpers::SlotData<void(const QColor &)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 },
        }}),
        // Slot 'slotBgColorSelected'
        QtMocHelpers::SlotData<void(const QColor &)>(86, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 },
        }}),
        // Slot 'slotReleasePosition'
        QtMocHelpers::SlotData<void(const QPointF &)>(87, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotFLagxValueChanged'
        QtMocHelpers::SlotData<void(int)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFLagyValueChanged'
        QtMocHelpers::SlotData<void(int)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotCenterxValueChanged'
        QtMocHelpers::SlotData<void(int)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCenteryValueChanged'
        QtMocHelpers::SlotData<void(int)>(92, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotAnchorxValueChanged'
        QtMocHelpers::SlotData<void(int)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotAnchoryValueChanged'
        QtMocHelpers::SlotData<void(int)>(94, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotCavalryxValueChanged'
        QtMocHelpers::SlotData<void(int)>(95, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCavalryyValueChanged'
        QtMocHelpers::SlotData<void(int)>(96, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotCannonxValueChanged'
        QtMocHelpers::SlotData<void(int)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCannonyValueChanged'
        QtMocHelpers::SlotData<void(int)>(98, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotInfantryxValueChanged'
        QtMocHelpers::SlotData<void(int)>(99, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotInfantryyValueChanged'
        QtMocHelpers::SlotData<void(int)>(100, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN15KsirkSkinEditor10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KsirkSkinEditor::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KsirkSkinEditor10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KsirkSkinEditor10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KsirkSkinEditor10MainWindowE_t>.metaTypes,
    nullptr
} };

void KsirkSkinEditor::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotShowAboutApplication(); break;
        case 1: _t->optionsConfigure(); break;
        case 2: _t->slotFlagButtonClicked(); break;
        case 3: _t->slotInfantryButtonClicked(); break;
        case 4: _t->slotCavalryButtonClicked(); break;
        case 5: _t->slotCannonButtonClicked(); break;
        case 6: _t->slotAnchorButtonClicked(); break;
        case 7: _t->slotCenterButtonClicked(); break;
        case 8: _t->slotPosition((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 9: _t->slotPressPosition((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 10: _t->slotCountrySelected((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 11: _t->slotContinentSelected((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 12: _t->slotItemPressed((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 13: _t->slotItemPlaced((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 14: _t->slotOpenSkin(); break;
        case 15: _t->slotSaveSkin(); break;
        case 16: _t->slotURLSelected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 17: _t->slotSkinNameEdited(); break;
        case 18: _t->slotSkinWidthEdited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->slotSkinHeightEdited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->slotSkinDescriptionEdited(); break;
        case 21: _t->slotSkinWidthDiffEdited(); break;
        case 22: _t->slotNewCountry(); break;
        case 23: _t->slotDeleteCountry(); break;
        case 24: _t->slotNeighbours(); break;
        case 25: _t->slotSkinPartTabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->slotContinentCountries(); break;
        case 27: _t->slotContinentBonusEdited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->slotFlagWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->slotFlagHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->slotFlagFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->slotFlagVersionsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slotInfantryWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->slotInfantryHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->slotInfantryFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->slotInfantryVersionsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->slotCavalryWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->slotCavalryHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->slotCavalryFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->slotCavalryVersionsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->slotCannonWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 41: _t->slotCannonHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 42: _t->slotCannonFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->slotCannonVersionsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->slotFiringWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->slotFiringHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 46: _t->slotFiringFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->slotFiringVersionsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->slotExplodingWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->slotExplodingHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 50: _t->slotExplodingFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->slotExplodingVersionsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->slotNewContinent(); break;
        case 53: _t->slotDeleteContinent(); break;
        case 54: _t->slotGoalSelected((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 55: _t->slotGoalTypeWorldClicked(); break;
        case 56: _t->slotGoalTypePlayerClicked(); break;
        case 57: _t->slotGoalTypeCountriesClicked(); break;
        case 58: _t->slotGoalTypeContinentsClicked(); break;
        case 59: _t->slotGoalDescriptionEdited(); break;
        case 60: _t->slotGoalNbCountriesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 61: _t->slotGoalNbArmiesByCountryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 62: _t->slotGoalAnyContinentChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: _t->slotGoalContinents(); break;
        case 64: _t->slotNewGoal(); break;
        case 65: _t->slotDeleteGoal(); break;
        case 66: _t->slotNationalitySelected((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 67: _t->slotNationalityNameEdited(); break;
        case 68: _t->slotNationalityLeaderNameEdited(); break;
        case 69: _t->slotNationalityFlagEdited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 70: _t->slotNewNationality(); break;
        case 71: _t->slotDeleteNationality(); break;
        case 72: _t->slotFontSelected((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 73: _t->slotFgSelected((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 74: _t->slotBgColorSelected((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 75: _t->slotReleasePosition((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 76: _t->slotFLagxValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 77: _t->slotFLagyValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 78: _t->slotCenterxValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 79: _t->slotCenteryValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 80: _t->slotAnchorxValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 81: _t->slotAnchoryValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 82: _t->slotCavalryxValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 83: _t->slotCavalryyValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 84: _t->slotCannonxValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 85: _t->slotCannonyValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 86: _t->slotInfantryxValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 87: _t->slotInfantryyValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KsirkSkinEditor::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KsirkSkinEditor::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KsirkSkinEditor10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KsirkSkinEditor::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 88)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 88;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 88)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 88;
    }
    return _id;
}
QT_WARNING_POP
