/********************************************************************************
** Form generated from reading UI file 'ksirkskineditorcountriesselectiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKSKINEDITORCOUNTRIESSELECTIONDIALOG_H
#define UI_KSIRKSKINEDITORCOUNTRIESSELECTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CountriesSelectionDialog
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *countriesList;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CountriesSelectionDialog)
    {
        if (CountriesSelectionDialog->objectName().isEmpty())
            CountriesSelectionDialog->setObjectName("CountriesSelectionDialog");
        CountriesSelectionDialog->resize(415, 609);
        verticalLayout = new QVBoxLayout(CountriesSelectionDialog);
        verticalLayout->setObjectName("verticalLayout");
        countriesList = new QListWidget(CountriesSelectionDialog);
        countriesList->setObjectName("countriesList");

        verticalLayout->addWidget(countriesList);

        buttonBox = new QDialogButtonBox(CountriesSelectionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CountriesSelectionDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CountriesSelectionDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CountriesSelectionDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CountriesSelectionDialog);
    } // setupUi

    void retranslateUi(QDialog *CountriesSelectionDialog)
    {
        CountriesSelectionDialog->setWindowTitle(tr2i18n("Country Selection Dialog", nullptr));
#if QT_CONFIG(tooltip)
        countriesList->setToolTip(tr2i18n("Country list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        countriesList->setWhatsThis(tr2i18n("List of all the countries defined in the world. Currently selected countries are highlighted. You can modify the selection using the mouse and Ctrl and Shift keys.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class CountriesSelectionDialog: public Ui_CountriesSelectionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKSKINEDITORCOUNTRIESSELECTIONDIALOG_H

