/********************************************************************************
** Form generated from reading UI file 'newGameSummary.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWGAMESUMMARY_H
#define UI_NEWGAMESUMMARY_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_NewGameSummary
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QLabel *skinNameLabel;
    QSpacerItem *horizontalSpacer_2;
    QLabel *skinSnapshotPixmap;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_5;
    QLabel *goalTypeLabel;
    QTableWidget *playersTable;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *previousButton;
    QPushButton *finishButton;

    void setupUi(QWidget *NewGameSummary)
    {
        if (NewGameSummary->objectName().isEmpty())
            NewGameSummary->setObjectName("NewGameSummary");
        NewGameSummary->resize(463, 432);
        verticalLayout_2 = new QVBoxLayout(NewGameSummary);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(NewGameSummary);
        label->setObjectName("label");
        QFont font;
        font.setPointSize(14);
        font.setBold(true);
        label->setFont(font);

        verticalLayout_2->addWidget(label);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_3 = new QLabel(NewGameSummary);
        label_3->setObjectName("label_3");
        QFont font1;
        font1.setBold(true);
        label_3->setFont(font1);

        horizontalLayout->addWidget(label_3);

        skinNameLabel = new QLabel(NewGameSummary);
        skinNameLabel->setObjectName("skinNameLabel");

        horizontalLayout->addWidget(skinNameLabel);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        skinSnapshotPixmap = new QLabel(NewGameSummary);
        skinSnapshotPixmap->setObjectName("skinSnapshotPixmap");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Ignored);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skinSnapshotPixmap->sizePolicy().hasHeightForWidth());
        skinSnapshotPixmap->setSizePolicy(sizePolicy);
        skinSnapshotPixmap->setScaledContents(true);
        skinSnapshotPixmap->setWordWrap(false);

        verticalLayout->addWidget(skinSnapshotPixmap);

        verticalLayout->setStretch(1, 1);

        verticalLayout_2->addLayout(verticalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(NewGameSummary);
        label_2->setObjectName("label_2");
        label_2->setFont(font1);

        horizontalLayout_2->addWidget(label_2);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        label_5 = new QLabel(NewGameSummary);
        label_5->setObjectName("label_5");
        label_5->setFont(font1);

        horizontalLayout_2->addWidget(label_5);

        goalTypeLabel = new QLabel(NewGameSummary);
        goalTypeLabel->setObjectName("goalTypeLabel");

        horizontalLayout_2->addWidget(goalTypeLabel);


        verticalLayout_2->addLayout(horizontalLayout_2);

        playersTable = new QTableWidget(NewGameSummary);
        if (playersTable->columnCount() < 4)
            playersTable->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setFont(font1);
        playersTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        __qtablewidgetitem1->setFont(font1);
        playersTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        __qtablewidgetitem2->setFont(font1);
        playersTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        __qtablewidgetitem3->setFont(font1);
        playersTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        playersTable->setObjectName("playersTable");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(playersTable->sizePolicy().hasHeightForWidth());
        playersTable->setSizePolicy(sizePolicy1);
        playersTable->horizontalHeader()->setCascadingSectionResizes(false);
        playersTable->verticalHeader()->setStretchLastSection(false);

        verticalLayout_2->addWidget(playersTable);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        cancelButton = new QPushButton(NewGameSummary);
        cancelButton->setObjectName("cancelButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-cancel")));
        cancelButton->setIcon(icon);

        horizontalLayout_3->addWidget(cancelButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        previousButton = new QPushButton(NewGameSummary);
        previousButton->setObjectName("previousButton");

        horizontalLayout_3->addWidget(previousButton);

        finishButton = new QPushButton(NewGameSummary);
        finishButton->setObjectName("finishButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("dialog-ok")));
        finishButton->setIcon(icon1);

        horizontalLayout_3->addWidget(finishButton);


        verticalLayout_2->addLayout(horizontalLayout_3);

        QWidget::setTabOrder(finishButton, previousButton);
        QWidget::setTabOrder(previousButton, cancelButton);
        QWidget::setTabOrder(cancelButton, playersTable);

        retranslateUi(NewGameSummary);

        QMetaObject::connectSlotsByName(NewGameSummary);
    } // setupUi

    void retranslateUi(QWidget *NewGameSummary)
    {
        label->setText(tr2i18n("New Game Summary", nullptr));
        label_3->setText(tr2i18n("Skin:", nullptr));
        skinNameLabel->setText(tr2i18n("skin name", nullptr));
        skinSnapshotPixmap->setText(QString());
        label_2->setText(tr2i18n("Players", nullptr));
        label_5->setText(tr2i18n("Goal type:", nullptr));
        goalTypeLabel->setText(tr2i18n("goal type", nullptr));
        QTableWidgetItem *___qtablewidgetitem = playersTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = playersTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Nationality", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = playersTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Computer", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = playersTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Network", nullptr));
        cancelButton->setText(tr2i18n("Cancel", nullptr));
        previousButton->setText(tr2i18n("Previous", nullptr));
        finishButton->setText(tr2i18n("Start", nullptr));
        (void)NewGameSummary;
    } // retranslateUi

};

namespace Ui {
    class NewGameSummary: public Ui_NewGameSummary {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWGAMESUMMARY_H

