/********************************************************************************
** Form generated from reading UI file 'ksirkcontinentdefinition.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKCONTINENTDEFINITION_H
#define UI_KSIRKCONTINENTDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KsirkContinentDefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *bonus;
    QPushButton *selectcountriesbutton;
    QListWidget *countrieslist;

    void setupUi(QDockWidget *KsirkContinentDefinition)
    {
        if (KsirkContinentDefinition->objectName().isEmpty())
            KsirkContinentDefinition->setObjectName("KsirkContinentDefinition");
        KsirkContinentDefinition->resize(288, 550);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(dockWidgetContents);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        bonus = new QSpinBox(dockWidgetContents);
        bonus->setObjectName("bonus");

        horizontalLayout->addWidget(bonus);


        verticalLayout->addLayout(horizontalLayout);

        selectcountriesbutton = new QPushButton(dockWidgetContents);
        selectcountriesbutton->setObjectName("selectcountriesbutton");

        verticalLayout->addWidget(selectcountriesbutton);

        countrieslist = new QListWidget(dockWidgetContents);
        countrieslist->setObjectName("countrieslist");

        verticalLayout->addWidget(countrieslist);

        KsirkContinentDefinition->setWidget(dockWidgetContents);

        retranslateUi(KsirkContinentDefinition);

        QMetaObject::connectSlotsByName(KsirkContinentDefinition);
    } // setupUi

    void retranslateUi(QDockWidget *KsirkContinentDefinition)
    {
        KsirkContinentDefinition->setWindowTitle(tr2i18n("Continent", nullptr));
        label->setText(tr2i18n("Bonus:", nullptr));
#if QT_CONFIG(tooltip)
        bonus->setToolTip(tr2i18n("Number of bonus points when owning the full continent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        bonus->setWhatsThis(tr2i18n("Number of bonus points when owning the full continent.\n"
"\n"
"At the end of each turn a number of armies is distributed to each player. If one player owns all the countries of this continent, he/she gains this bonus.\n"
"\n"
"The bonus should be proportional to the continent's size and to the difficulty to conquer it or to keep it.", nullptr));
#endif // QT_CONFIG(whatsthis)
        bonus->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        selectcountriesbutton->setToolTip(tr2i18n("Select the countries contained in this continent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        selectcountriesbutton->setWhatsThis(tr2i18n("Click here to select the countries contained in this continent.\n"
"\n"
"A list of all the world's countries will be shown and you will be able to select the countries using the mouse and the Ctrl and Shift keys.", nullptr));
#endif // QT_CONFIG(whatsthis)
        selectcountriesbutton->setText(tr2i18n("Countries:", nullptr));
#if QT_CONFIG(tooltip)
        countrieslist->setToolTip(tr2i18n("Continent's countries", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        countrieslist->setWhatsThis(tr2i18n("This is the list of countries currently forming this continent.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class KsirkContinentDefinition: public Ui_KsirkContinentDefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKCONTINENTDEFINITION_H

