/*
    <one line to give the program's name and a brief idea of what it does.>
    Copyright (C) <year>  <name of author>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either either version 2
   of the License, or (at your option) any later version.of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "newplayerdata.h"

using namespace Ksirk;

NewPlayerData::NewPlayerData(const QString& name, const QString& nation, const QString& password, bool computer, bool network) :
  m_name(name),
  m_nation(nation),
  m_password(password),
  m_computer(computer),
  m_network(network)
{
}
