/****************************************************************************
** Meta object code from reading C++ file 'gameautomaton.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksirk-26.07.80/ksirk/GameLogic/gameautomaton.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gameautomaton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Ksirk9GameLogic13GameAutomatonE_t {};
} // unnamed namespace

template <> constexpr inline auto Ksirk::GameLogic::GameAutomaton::qt_create_metaobjectdata<qt_meta_tag_ZN5Ksirk9GameLogic13GameAutomatonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ksirk::GameLogic::GameAutomaton",
        "run",
        "GameState",
        "",
        "slotPropertyChanged",
        "KGamePropertyBase*",
        "prop",
        "KGame*",
        "game",
        "slotPlayerJoinedGame",
        "KPlayer*",
        "player",
        "slotNetworkData",
        "msgid",
        "buffer",
        "receiver",
        "sender",
        "slotClientJoinedGame",
        "clientid",
        "me",
        "slotConnectionToServerBroken",
        "slotConnectionToClientBroken",
        "KMessageIO*",
        "getDefCountry",
        "Country*",
        "displayGoals"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'run'
        QtMocHelpers::SlotData<enum GameState()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'slotPropertyChanged'
        QtMocHelpers::SlotData<void(KGamePropertyBase *, KGame *)>(4, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'slotPlayerJoinedGame'
        QtMocHelpers::SlotData<void(KPlayer *)>(9, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotNetworkData'
        QtMocHelpers::SlotData<void(int, const QByteArray &, quint32, quint32)>(12, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::QByteArray, 14 }, { QMetaType::UInt, 15 }, { QMetaType::UInt, 16 },
        }}),
        // Slot 'slotClientJoinedGame'
        QtMocHelpers::SlotData<void(quint32, KGame *)>(17, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 18 }, { 0x80000000 | 7, 19 },
        }}),
        // Slot 'slotConnectionToServerBroken'
        QtMocHelpers::SlotData<void()>(20, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConnectionToClientBroken'
        QtMocHelpers::SlotData<void(KMessageIO *)>(21, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 3 },
        }}),
        // Slot 'getDefCountry'
        QtMocHelpers::SlotData<Country *()>(23, 3, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'displayGoals'
        QtMocHelpers::SlotData<void()>(25, 3, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GameAutomaton, qt_meta_tag_ZN5Ksirk9GameLogic13GameAutomatonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ksirk::GameLogic::GameAutomaton::staticMetaObject = { {
    QMetaObject::SuperData::link<KGame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk9GameLogic13GameAutomatonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk9GameLogic13GameAutomatonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Ksirk9GameLogic13GameAutomatonE_t>.metaTypes,
    nullptr
} };

void Ksirk::GameLogic::GameAutomaton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GameAutomaton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { enum GameState _r = _t->run();
            if (_a[0]) *reinterpret_cast<enum GameState*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->slotPropertyChanged((*reinterpret_cast<std::add_pointer_t<KGamePropertyBase*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGame*>>(_a[2]))); break;
        case 2: _t->slotPlayerJoinedGame((*reinterpret_cast<std::add_pointer_t<KPlayer*>>(_a[1]))); break;
        case 3: _t->slotNetworkData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[4]))); break;
        case 4: _t->slotClientJoinedGame((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGame*>>(_a[2]))); break;
        case 5: _t->slotConnectionToServerBroken(); break;
        case 6: _t->slotConnectionToClientBroken((*reinterpret_cast<std::add_pointer_t<KMessageIO*>>(_a[1]))); break;
        case 7: { Country* _r = _t->getDefCountry();
            if (_a[0]) *reinterpret_cast<Country**>(_a[0]) = std::move(_r); }  break;
        case 8: _t->displayGoals(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGame* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPlayer* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGame* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KMessageIO* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Ksirk::GameLogic::GameAutomaton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::GameLogic::GameAutomaton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk9GameLogic13GameAutomatonE_t>.strings))
        return static_cast<void*>(this);
    return KGame::qt_metacast(_clname);
}

int Ksirk::GameLogic::GameAutomaton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
