/****************************************************************************
** Meta object code from reading C++ file 'kgamewin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksirk-26.07.80/ksirk/kgamewin.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgamewin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Ksirk11KGameWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Ksirk::KGameWindow::qt_create_metaobjectdata<qt_meta_tag_ZN5Ksirk11KGameWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ksirk::KGameWindow",
        "mouseMoveEvent",
        "",
        "QMouseEvent*",
        "event",
        "slotNewGame",
        "slotNewSocketGame",
        "slotJoinNetworkGame",
        "slotOpenGame",
        "slotSaveGame",
        "slotRecycling",
        "slotRecyclingFinished",
        "slotNextPlayer",
        "slotAttack1",
        "slotAttack2",
        "slotAttack3",
        "slotDefense1",
        "slotDefense2",
        "slotDefAuto",
        "slotWindowDef1",
        "slotWindowDef2",
        "slotInvade1",
        "slotInvade5",
        "slotInvade10",
        "slotInvasionFinished",
        "slotRetreat1",
        "slotRetreat5",
        "slotRetreat10",
        "slotMove",
        "slotCancel",
        "slotDumpGameInformations",
        "slotFinishMoves",
        "slotArena",
        "slotContextualHelp",
        "slotShowAboutApplication",
        "slotLeftButtonDown",
        "QPointF",
        "slotLeftButtonUp",
        "slotRightButtonDown",
        "slotRightButtonUp",
        "slotShowGoal",
        "slotChatMessage",
        "slotChatReduceButton",
        "slotChatFloatButtonPressed",
        "slotChatFloatChanged",
        "value",
        "slotMovingFightersArrived",
        "AnimSpritesGroup*",
        "sprites",
        "slotFiringFinished",
        "slotExplosionFinished",
        "slotMovingArmiesArrived",
        "slotBring",
        "AnimSprite*",
        "slotMovingArmyArrived",
        "slotZoomIn",
        "slotZoomOut",
        "slotNewGameNext",
        "slotNewGameKO",
        "slotNewPlayerNext",
        "slotNewPlayerPrevious",
        "slotNewPlayerCancel",
        "slotStartNewGame",
        "slotTcpConnectCancel",
        "slotTcpConnectPrevious",
        "optionsConfigure",
        "evenementTimer",
        "slotRemoveMessage",
        "slotDisableHelp",
        "slotArmiesNumberChanged",
        "slotExit",
        "slotConnectToServer"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'mouseMoveEvent'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotNewGame'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewSocketGame'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotJoinNetworkGame'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenGame'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveGame'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRecycling'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRecyclingFinished'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNextPlayer'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAttack1'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAttack2'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAttack3'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDefense1'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDefense2'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDefAuto'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowDef1'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWindowDef2'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInvade1'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInvade5'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInvade10'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInvasionFinished'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRetreat1'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRetreat5'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRetreat10'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMove'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCancel'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDumpGameInformations'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFinishMoves'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotArena'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotContextualHelp'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowAboutApplication'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLeftButtonDown'
        QtMocHelpers::SlotData<void(const QPointF &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotLeftButtonUp'
        QtMocHelpers::SlotData<void(const QPointF &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotRightButtonDown'
        QtMocHelpers::SlotData<void(const QPointF &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotRightButtonUp'
        QtMocHelpers::SlotData<void(const QPointF &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotShowGoal'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChatMessage'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChatReduceButton'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChatFloatButtonPressed'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChatFloatChanged'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'slotChatFloatChanged'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotMovingFightersArrived'
        QtMocHelpers::SlotData<void(AnimSpritesGroup *)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'slotFiringFinished'
        QtMocHelpers::SlotData<void(AnimSpritesGroup *)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 2 },
        }}),
        // Slot 'slotExplosionFinished'
        QtMocHelpers::SlotData<void(AnimSpritesGroup *)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 2 },
        }}),
        // Slot 'slotMovingArmiesArrived'
        QtMocHelpers::SlotData<void(AnimSpritesGroup *)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 2 },
        }}),
        // Slot 'slotBring'
        QtMocHelpers::SlotData<void(AnimSprite *)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 2 },
        }}),
        // Slot 'slotMovingArmyArrived'
        QtMocHelpers::SlotData<void(AnimSprite *)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 2 },
        }}),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewGameNext'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewGameKO'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewPlayerNext'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewPlayerPrevious'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewPlayerCancel'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStartNewGame'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTcpConnectCancel'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTcpConnectPrevious'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'optionsConfigure'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'evenementTimer'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveMessage'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDisableHelp'
        QtMocHelpers::SlotData<void(const QString &)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotArmiesNumberChanged'
        QtMocHelpers::SlotData<void(bool)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotExit'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConnectToServer'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGameWindow, qt_meta_tag_ZN5Ksirk11KGameWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ksirk::KGameWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk11KGameWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk11KGameWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Ksirk11KGameWindowE_t>.metaTypes,
    nullptr
} };

void Ksirk::KGameWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGameWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mouseMoveEvent((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 1: _t->slotNewGame(); break;
        case 2: _t->slotNewSocketGame(); break;
        case 3: _t->slotJoinNetworkGame(); break;
        case 4: _t->slotOpenGame(); break;
        case 5: _t->slotSaveGame(); break;
        case 6: _t->slotRecycling(); break;
        case 7: _t->slotRecyclingFinished(); break;
        case 8: _t->slotNextPlayer(); break;
        case 9: _t->slotAttack1(); break;
        case 10: _t->slotAttack2(); break;
        case 11: _t->slotAttack3(); break;
        case 12: _t->slotDefense1(); break;
        case 13: _t->slotDefense2(); break;
        case 14: _t->slotDefAuto(); break;
        case 15: _t->slotWindowDef1(); break;
        case 16: _t->slotWindowDef2(); break;
        case 17: _t->slotInvade1(); break;
        case 18: _t->slotInvade5(); break;
        case 19: _t->slotInvade10(); break;
        case 20: _t->slotInvasionFinished(); break;
        case 21: _t->slotRetreat1(); break;
        case 22: _t->slotRetreat5(); break;
        case 23: _t->slotRetreat10(); break;
        case 24: _t->slotMove(); break;
        case 25: _t->slotCancel(); break;
        case 26: _t->slotDumpGameInformations(); break;
        case 27: _t->slotFinishMoves(); break;
        case 28: _t->slotArena((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->slotContextualHelp(); break;
        case 30: _t->slotShowAboutApplication(); break;
        case 31: _t->slotLeftButtonDown((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 32: _t->slotLeftButtonUp((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 33: _t->slotRightButtonDown((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 34: _t->slotRightButtonUp((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 35: _t->slotShowGoal(); break;
        case 36: _t->slotChatMessage(); break;
        case 37: _t->slotChatReduceButton(); break;
        case 38: _t->slotChatFloatButtonPressed(); break;
        case 39: _t->slotChatFloatChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->slotChatFloatChanged(); break;
        case 41: _t->slotMovingFightersArrived((*reinterpret_cast<std::add_pointer_t<AnimSpritesGroup*>>(_a[1]))); break;
        case 42: _t->slotFiringFinished((*reinterpret_cast<std::add_pointer_t<AnimSpritesGroup*>>(_a[1]))); break;
        case 43: _t->slotExplosionFinished((*reinterpret_cast<std::add_pointer_t<AnimSpritesGroup*>>(_a[1]))); break;
        case 44: _t->slotMovingArmiesArrived((*reinterpret_cast<std::add_pointer_t<AnimSpritesGroup*>>(_a[1]))); break;
        case 45: _t->slotBring((*reinterpret_cast<std::add_pointer_t<AnimSprite*>>(_a[1]))); break;
        case 46: _t->slotMovingArmyArrived((*reinterpret_cast<std::add_pointer_t<AnimSprite*>>(_a[1]))); break;
        case 47: _t->slotZoomIn(); break;
        case 48: _t->slotZoomOut(); break;
        case 49: _t->slotNewGameNext(); break;
        case 50: _t->slotNewGameKO(); break;
        case 51: _t->slotNewPlayerNext(); break;
        case 52: _t->slotNewPlayerPrevious(); break;
        case 53: _t->slotNewPlayerCancel(); break;
        case 54: _t->slotStartNewGame(); break;
        case 55: _t->slotTcpConnectCancel(); break;
        case 56: _t->slotTcpConnectPrevious(); break;
        case 57: _t->optionsConfigure(); break;
        case 58: _t->evenementTimer(); break;
        case 59: _t->slotRemoveMessage(); break;
        case 60: _t->slotDisableHelp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 61: _t->slotArmiesNumberChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->slotExit(); break;
        case 63: _t->slotConnectToServer(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AnimSprite* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AnimSprite* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Ksirk::KGameWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::KGameWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Ksirk11KGameWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Ksirk::KGameWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    return _id;
}
QT_WARNING_POP
