/********************************************************************************
** Form generated from reading UI file 'ksirknationalitydefinition.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKNATIONALITYDEFINITION_H
#define UI_KSIRKNATIONALITYDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_KsirkNationalityDefinition
{
public:
    QWidget *dockWidgetContents;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *name;
    QLabel *label_2;
    QLineEdit *leader;
    QLabel *label_3;
    KComboBox *flag;
    QSpacerItem *verticalSpacer;

    void setupUi(QDockWidget *KsirkNationalityDefinition)
    {
        if (KsirkNationalityDefinition->objectName().isEmpty())
            KsirkNationalityDefinition->setObjectName("KsirkNationalityDefinition");
        KsirkNationalityDefinition->resize(288, 550);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        gridLayout = new QGridLayout(dockWidgetContents);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(dockWidgetContents);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 2);

        name = new QLineEdit(dockWidgetContents);
        name->setObjectName("name");
        name->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(name, 0, 2, 1, 1);

        label_2 = new QLabel(dockWidgetContents);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        leader = new QLineEdit(dockWidgetContents);
        leader->setObjectName("leader");

        gridLayout->addWidget(leader, 1, 2, 1, 1);

        label_3 = new QLabel(dockWidgetContents);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 2);

        flag = new KComboBox(dockWidgetContents);
        flag->setObjectName("flag");

        gridLayout->addWidget(flag, 2, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 384, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 1, 1, 2);

        KsirkNationalityDefinition->setWidget(dockWidgetContents);

        retranslateUi(KsirkNationalityDefinition);

        QMetaObject::connectSlotsByName(KsirkNationalityDefinition);
    } // setupUi

    void retranslateUi(QDockWidget *KsirkNationalityDefinition)
    {
        KsirkNationalityDefinition->setWindowTitle(tr2i18n("Nationality", nullptr));
        label->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        name->setToolTip(tr2i18n("Nationality name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        name->setWhatsThis(tr2i18n("<p>Nationality name. The name of the player country. Can be the name of an existing country in case of a <i>realistic</i> world.</p><p>This string should be unique in the skin.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        name->setText(QString());
        label_2->setText(tr2i18n("Leader name:", nullptr));
#if QT_CONFIG(tooltip)
        leader->setToolTip(tr2i18n("Leader name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        leader->setWhatsThis(tr2i18n("<p>Name of this nationality leader. In the case of a <i>realistic</i> skin, this could be the name of a well known king, president, etc.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Flag ID in pool:", nullptr));
#if QT_CONFIG(tooltip)
        flag->setToolTip(tr2i18n("Flag sprite id in the pool SVG", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        flag->setWhatsThis(tr2i18n("Flag sprite id in the pool SVG (pool.svg).", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class KsirkNationalityDefinition: public Ui_KsirkNationalityDefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKNATIONALITYDEFINITION_H

