/********************************************************************************
** Form generated from reading UI file 'ksirkgoaldefinition.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKGOALDEFINITION_H
#define UI_KSIRKGOALDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KsirkGoalDefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QRadioButton *worldtype;
    QRadioButton *playertype;
    QRadioButton *countriestype;
    QRadioButton *continentstype;
    QLabel *label_3;
    QTextEdit *description;
    QFrame *line_2;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QSpinBox *nbcountries;
    QSpinBox *armiesbycountry;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QPushButton *selectcontinentsbutton;
    QCheckBox *anycontinent;
    QListWidget *continentslist;

    void setupUi(QDockWidget *KsirkGoalDefinition)
    {
        if (KsirkGoalDefinition->objectName().isEmpty())
            KsirkGoalDefinition->setObjectName("KsirkGoalDefinition");
        KsirkGoalDefinition->resize(288, 772);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout_2 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(dockWidgetContents);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        layoutWidget = new QWidget(groupBox);
        layoutWidget->setObjectName("layoutWidget");
        layoutWidget->setGeometry(QRect(20, 40, 221, 118));
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        worldtype = new QRadioButton(layoutWidget);
        worldtype->setObjectName("worldtype");

        verticalLayout->addWidget(worldtype);

        playertype = new QRadioButton(layoutWidget);
        playertype->setObjectName("playertype");

        verticalLayout->addWidget(playertype);

        countriestype = new QRadioButton(layoutWidget);
        countriestype->setObjectName("countriestype");

        verticalLayout->addWidget(countriestype);

        continentstype = new QRadioButton(layoutWidget);
        continentstype->setObjectName("continentstype");

        verticalLayout->addWidget(continentstype);


        verticalLayout_2->addWidget(groupBox);

        label_3 = new QLabel(dockWidgetContents);
        label_3->setObjectName("label_3");

        verticalLayout_2->addWidget(label_3);

        description = new QTextEdit(dockWidgetContents);
        description->setObjectName("description");

        verticalLayout_2->addWidget(description);

        line_2 = new QFrame(dockWidgetContents);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(dockWidgetContents);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(dockWidgetContents);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        nbcountries = new QSpinBox(dockWidgetContents);
        nbcountries->setObjectName("nbcountries");

        gridLayout->addWidget(nbcountries, 0, 1, 1, 1);

        armiesbycountry = new QSpinBox(dockWidgetContents);
        armiesbycountry->setObjectName("armiesbycountry");

        gridLayout->addWidget(armiesbycountry, 1, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        line = new QFrame(dockWidgetContents);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        selectcontinentsbutton = new QPushButton(dockWidgetContents);
        selectcontinentsbutton->setObjectName("selectcontinentsbutton");

        horizontalLayout->addWidget(selectcontinentsbutton);

        anycontinent = new QCheckBox(dockWidgetContents);
        anycontinent->setObjectName("anycontinent");

        horizontalLayout->addWidget(anycontinent);


        verticalLayout_2->addLayout(horizontalLayout);

        continentslist = new QListWidget(dockWidgetContents);
        continentslist->setObjectName("continentslist");

        verticalLayout_2->addWidget(continentslist);

        KsirkGoalDefinition->setWidget(dockWidgetContents);

        retranslateUi(KsirkGoalDefinition);

        QMetaObject::connectSlotsByName(KsirkGoalDefinition);
    } // setupUi

    void retranslateUi(QDockWidget *KsirkGoalDefinition)
    {
        KsirkGoalDefinition->setWindowTitle(tr2i18n("Goal", nullptr));
        groupBox->setTitle(tr2i18n("Goal Type", nullptr));
#if QT_CONFIG(tooltip)
        worldtype->setToolTip(tr2i18n("Conquer all the world", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        worldtype->setWhatsThis(tr2i18n("Conquer all the world", nullptr));
#endif // QT_CONFIG(whatsthis)
        worldtype->setText(tr2i18n("World conquest", nullptr));
#if QT_CONFIG(tooltip)
        playertype->setToolTip(tr2i18n("Eliminate a given player", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        playertype->setWhatsThis(tr2i18n("<p>Eliminate a given player. If it is eliminated by another one, you will fall back to a <emphasis>Countries</emphasis> type of goal.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        playertype->setText(tr2i18n("Player", nullptr));
#if QT_CONFIG(tooltip)
        countriestype->setToolTip(tr2i18n("Conquer a given number of countries", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        countriestype->setWhatsThis(tr2i18n("Conquer a given number of countries.\n"
"\n"
"You can also make the player to have to put a given number of armies on each country.", nullptr));
#endif // QT_CONFIG(whatsthis)
        countriestype->setText(tr2i18n("Countries", nullptr));
#if QT_CONFIG(tooltip)
        continentstype->setToolTip(tr2i18n("Conquer a given list of continents", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        continentstype->setWhatsThis(tr2i18n("Conquer a given list of continents. You can also let the player choose one of their target continents.", nullptr));
#endif // QT_CONFIG(whatsthis)
        continentstype->setText(tr2i18n("Continents", nullptr));
        label_3->setText(tr2i18n("Description:", nullptr));
#if QT_CONFIG(tooltip)
        description->setToolTip(tr2i18n("Text describing the goal", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        description->setWhatsThis(tr2i18n("<p>Text describing the goal. It should include several placeholders for various data depending on the goal type:</p><ul><li><i>World Conquest</i>: none</li><li><i>Player</i>: one for the player name and one for the number of countries fallback</li><li><i>Countries</i>: one for the number of countries and possibly a second one for the number of armies to put on each country</li><li><i>Continents</i>: one for each continent to conquer</li></ul>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Countries nb:", nullptr));
        label_2->setText(tr2i18n("Armies by country:", nullptr));
#if QT_CONFIG(tooltip)
        nbcountries->setToolTip(tr2i18n("Number of countries to conquer", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        nbcountries->setWhatsThis(tr2i18n("<p>Number of countries to conquer in a <i>Countries</i> goal or as a fallback in a <i>Player</i> goal.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        armiesbycountry->setToolTip(tr2i18n("Number of armies to put on each country", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        armiesbycountry->setWhatsThis(tr2i18n("<p>Number of armies to put on each country in a <i>Countries</i> goal.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        selectcontinentsbutton->setToolTip(tr2i18n("Select the continents to conquer", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        selectcontinentsbutton->setWhatsThis(tr2i18n("<p>Click this button to select the continents to conquer in a <i>Continents</i> goal.</p><p>You will be prompted with a list of this world's continents. Select those to conquer with the mouse and the Ctrl and Shift keys.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        selectcontinentsbutton->setText(tr2i18n("Select Continents", nullptr));
#if QT_CONFIG(tooltip)
        anycontinent->setToolTip(tr2i18n("Check to let the player choose one of the continents to conquer", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        anycontinent->setWhatsThis(tr2i18n("Check to let the player choose one of the continents to conquer", nullptr));
#endif // QT_CONFIG(whatsthis)
        anycontinent->setText(tr2i18n("Any", nullptr));
#if QT_CONFIG(tooltip)
        continentslist->setToolTip(tr2i18n("List of the continents to conquer", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        continentslist->setWhatsThis(tr2i18n("<p>List of the continents to conquer in a <i>Continents</i> goal.</p><p>You can change this list by clicking on the \"Select continents\" button above.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class KsirkGoalDefinition: public Ui_KsirkGoalDefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKGOALDEFINITION_H

