/********************************************************************************
** Form generated from reading UI file 'mainMenu.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINMENU_H
#define UI_MAINMENU_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MainMenu
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_4;
    QLabel *lImage1;
    QLabel *lTitle;
    QLabel *lImage2;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QPushButton *pbNewGame;
    QPushButton *pbNewSocketGame;
    QPushButton *pbJoin;
    QPushButton *pbLoad;
    QSpacerItem *verticalSpacer;
    QPushButton *pbQuit;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *MainMenu)
    {
        if (MainMenu->objectName().isEmpty())
            MainMenu->setObjectName("MainMenu");
        MainMenu->resize(596, 364);
        verticalLayout_2 = new QVBoxLayout(MainMenu);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);

        lImage1 = new QLabel(MainMenu);
        lImage1->setObjectName("lImage1");
        lImage1->setText(QString::fromUtf8("LeftImg"));

        horizontalLayout->addWidget(lImage1);

        lTitle = new QLabel(MainMenu);
        lTitle->setObjectName("lTitle");

        horizontalLayout->addWidget(lTitle);

        lImage2 = new QLabel(MainMenu);
        lImage2->setObjectName("lImage2");
        lImage2->setText(QString::fromUtf8("RightImg"));

        horizontalLayout->addWidget(lImage2);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer_2 = new QSpacerItem(20, 28, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        pbNewGame = new QPushButton(MainMenu);
        pbNewGame->setObjectName("pbNewGame");

        verticalLayout->addWidget(pbNewGame);

        pbNewSocketGame = new QPushButton(MainMenu);
        pbNewSocketGame->setObjectName("pbNewSocketGame");

        verticalLayout->addWidget(pbNewSocketGame);

        pbJoin = new QPushButton(MainMenu);
        pbJoin->setObjectName("pbJoin");

        verticalLayout->addWidget(pbJoin);

        pbLoad = new QPushButton(MainMenu);
        pbLoad->setObjectName("pbLoad");

        verticalLayout->addWidget(pbLoad);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        pbQuit = new QPushButton(MainMenu);
        pbQuit->setObjectName("pbQuit");

        verticalLayout->addWidget(pbQuit);


        horizontalLayout_2->addLayout(verticalLayout);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 28, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);


        retranslateUi(MainMenu);

        QMetaObject::connectSlotsByName(MainMenu);
    } // setupUi

    void retranslateUi(QWidget *MainMenu)
    {
        lTitle->setText(tr2i18n("<h1>KsirK</h1>", nullptr));
        pbNewGame->setText(tr2i18n("New Local Game", nullptr));
        pbNewSocketGame->setText(tr2i18n("New Standard TCP/IP Network Game", nullptr));
        pbJoin->setText(tr2i18n("Join Standard TCP/IP Network Game", nullptr));
        pbLoad->setText(tr2i18n("Load\342\200\246", nullptr));
        pbQuit->setText(tr2i18n("Quit", nullptr));
        (void)MainMenu;
    } // retranslateUi

};

namespace Ui {
    class MainMenu: public Ui_MainMenu {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAINMENU_H

