/********************************************************************************
** Form generated from reading UI file 'preferences.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCES_H
#define UI_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KsirkPreferencesWidget
{
public:
    QGridLayout *gridLayout;
    QCheckBox *kcfg_soundEnabled;
    QLabel *textLabel1;
    QSlider *kcfg_spritesSpeed;
    QCheckBox *kcfg_helpEnabled;
    QCheckBox *kcfg_showArmiesNumbers;

    void setupUi(QWidget *KsirkPreferencesWidget)
    {
        if (KsirkPreferencesWidget->objectName().isEmpty())
            KsirkPreferencesWidget->setObjectName("KsirkPreferencesWidget");
        KsirkPreferencesWidget->resize(533, 294);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(15);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KsirkPreferencesWidget->sizePolicy().hasHeightForWidth());
        KsirkPreferencesWidget->setSizePolicy(sizePolicy);
        KsirkPreferencesWidget->setMinimumSize(QSize(100, 100));
        gridLayout = new QGridLayout(KsirkPreferencesWidget);
        gridLayout->setObjectName("gridLayout");
        kcfg_soundEnabled = new QCheckBox(KsirkPreferencesWidget);
        kcfg_soundEnabled->setObjectName("kcfg_soundEnabled");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_soundEnabled->sizePolicy().hasHeightForWidth());
        kcfg_soundEnabled->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(kcfg_soundEnabled, 0, 0, 1, 1);

        textLabel1 = new QLabel(KsirkPreferencesWidget);
        textLabel1->setObjectName("textLabel1");
        sizePolicy1.setHeightForWidth(textLabel1->sizePolicy().hasHeightForWidth());
        textLabel1->setSizePolicy(sizePolicy1);
        textLabel1->setWordWrap(false);

        gridLayout->addWidget(textLabel1, 1, 0, 1, 1);

        kcfg_spritesSpeed = new QSlider(KsirkPreferencesWidget);
        kcfg_spritesSpeed->setObjectName("kcfg_spritesSpeed");
        sizePolicy1.setHeightForWidth(kcfg_spritesSpeed->sizePolicy().hasHeightForWidth());
        kcfg_spritesSpeed->setSizePolicy(sizePolicy1);
        kcfg_spritesSpeed->setMinimum(0);
        kcfg_spritesSpeed->setMaximum(3);
        kcfg_spritesSpeed->setPageStep(1);
        kcfg_spritesSpeed->setValue(1);
        kcfg_spritesSpeed->setOrientation(Qt::Horizontal);
        kcfg_spritesSpeed->setTickInterval(1);

        gridLayout->addWidget(kcfg_spritesSpeed, 2, 0, 1, 1);

        kcfg_helpEnabled = new QCheckBox(KsirkPreferencesWidget);
        kcfg_helpEnabled->setObjectName("kcfg_helpEnabled");
        sizePolicy1.setHeightForWidth(kcfg_helpEnabled->sizePolicy().hasHeightForWidth());
        kcfg_helpEnabled->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(kcfg_helpEnabled, 3, 0, 1, 1);

        kcfg_showArmiesNumbers = new QCheckBox(KsirkPreferencesWidget);
        kcfg_showArmiesNumbers->setObjectName("kcfg_showArmiesNumbers");

        gridLayout->addWidget(kcfg_showArmiesNumbers, 4, 0, 1, 1);


        retranslateUi(KsirkPreferencesWidget);

        QMetaObject::connectSlotsByName(KsirkPreferencesWidget);
    } // setupUi

    void retranslateUi(QWidget *KsirkPreferencesWidget)
    {
        kcfg_soundEnabled->setText(tr2i18n("Sound enabled", nullptr));
        textLabel1->setText(tr2i18n("Sprites speed (slow, normal, rapid, immediate):", nullptr));
        kcfg_helpEnabled->setText(tr2i18n("Show help", nullptr));
        kcfg_showArmiesNumbers->setText(tr2i18n("Show number of armies on countries", nullptr));
        (void)KsirkPreferencesWidget;
    } // retranslateUi

};

namespace Ui {
    class KsirkPreferencesWidget: public Ui_KsirkPreferencesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCES_H

