/********************************************************************************
** Form generated from reading UI file 'restartOrExitDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESTARTOREXITDIALOG_H
#define UI_RESTARTOREXITDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RestartOrExitDialog
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *newGameButton;
    QPushButton *doNothingButton;
    QPushButton *exitButton;
    QSpacerItem *spacer1;
    QLabel *messageLabel;

    void setupUi(QDialog *RestartOrExitDialog)
    {
        if (RestartOrExitDialog->objectName().isEmpty())
            RestartOrExitDialog->setObjectName("RestartOrExitDialog");
        RestartOrExitDialog->resize(385, 229);
        gridLayout = new QGridLayout(RestartOrExitDialog);
        gridLayout->setObjectName("gridLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        newGameButton = new QPushButton(RestartOrExitDialog);
        newGameButton->setObjectName("newGameButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-new")));
        newGameButton->setIcon(icon);

        hboxLayout->addWidget(newGameButton);

        doNothingButton = new QPushButton(RestartOrExitDialog);
        doNothingButton->setObjectName("doNothingButton");

        hboxLayout->addWidget(doNothingButton);

        exitButton = new QPushButton(RestartOrExitDialog);
        exitButton->setObjectName("exitButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("application-exit")));
        exitButton->setIcon(icon1);

        hboxLayout->addWidget(exitButton);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 1);

        spacer1 = new QSpacerItem(31, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer1, 1, 0, 1, 1);

        messageLabel = new QLabel(RestartOrExitDialog);
        messageLabel->setObjectName("messageLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(messageLabel->sizePolicy().hasHeightForWidth());
        messageLabel->setSizePolicy(sizePolicy);
        messageLabel->setFrameShape(QFrame::NoFrame);
        messageLabel->setText(QString::fromUtf8("XYZ won! Do you want to play again?"));
        messageLabel->setWordWrap(false);

        gridLayout->addWidget(messageLabel, 0, 0, 1, 1);


        retranslateUi(RestartOrExitDialog);

        QMetaObject::connectSlotsByName(RestartOrExitDialog);
    } // setupUi

    void retranslateUi(QDialog *RestartOrExitDialog)
    {
        RestartOrExitDialog->setWindowTitle(tr2i18n("New Game or Exit", nullptr));
        newGameButton->setText(tr2i18n("New Game", nullptr));
#if QT_CONFIG(shortcut)
        newGameButton->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        newGameButton->setProperty("toolTip", QVariant(tr2i18n("Starts a new game", nullptr)));
#endif // QT_CONFIG(tooltip)
        doNothingButton->setText(tr2i18n("Do Nothing", nullptr));
#if QT_CONFIG(tooltip)
        doNothingButton->setProperty("toolTip", QVariant(tr2i18n("Do nothing. Game buttons will be available", nullptr)));
#endif // QT_CONFIG(tooltip)
        exitButton->setText(tr2i18n("Exit", nullptr));
#if QT_CONFIG(tooltip)
        exitButton->setProperty("toolTip", QVariant(tr2i18n("Quit KsirK", nullptr)));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class RestartOrExitDialog: public Ui_RestartOrExitDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESTARTOREXITDIALOG_H

