/********************************************************************************
** Form generated from reading UI file 'ksirkskindefinition.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKSKINDEFINITION_H
#define UI_KSIRKSKINDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_skindefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_7;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QLineEdit *skinNameLineEdit;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *widthLineEdit;
    QLabel *label_2;
    QSpinBox *heightLineEdit;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_5;
    KFontRequester *fontrequester;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_5;
    KColorButton *fgcolorbutton;
    QLabel *label_6;
    KColorButton *bgcolorbutton;
    QLabel *label_4;
    QTextEdit *descriptionTextEdit;
    QTabWidget *qtabwidget;
    QWidget *tabSprites;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_7;
    QWidget *tabNationalities;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_8;
    QPushButton *newNationalityButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *deleteNationalityButton;
    QListWidget *nationalitieslist;
    QWidget *tabCountries;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_5;
    QPushButton *newCountryButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *deleteCountryButton;
    QListWidget *countrieslist;
    QWidget *tabContinents;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_6;
    QPushButton *newContinentButton;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *deleteContinentButton;
    QListWidget *continentslist;
    QWidget *tabGoals;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_7;
    QPushButton *newGoalButton;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *deleteGoalButton;
    QListWidget *goalslist;

    void setupUi(QDockWidget *skindefinition)
    {
        if (skindefinition->objectName().isEmpty())
            skindefinition->setObjectName("skindefinition");
        skindefinition->resize(328, 841);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout_7 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_7->setObjectName("verticalLayout_7");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_3 = new QLabel(dockWidgetContents);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        skinNameLineEdit = new QLineEdit(dockWidgetContents);
        skinNameLineEdit->setObjectName("skinNameLineEdit");

        horizontalLayout_2->addWidget(skinNameLineEdit);


        verticalLayout_7->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(dockWidgetContents);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        widthLineEdit = new QSpinBox(dockWidgetContents);
        widthLineEdit->setObjectName("widthLineEdit");

        horizontalLayout->addWidget(widthLineEdit);

        label_2 = new QLabel(dockWidgetContents);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        heightLineEdit = new QSpinBox(dockWidgetContents);
        heightLineEdit->setObjectName("heightLineEdit");

        horizontalLayout->addWidget(heightLineEdit);


        verticalLayout_7->addLayout(horizontalLayout);

        groupBox = new QGroupBox(dockWidgetContents);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        verticalLayout_5 = new QVBoxLayout(groupBox);
        verticalLayout_5->setObjectName("verticalLayout_5");
        fontrequester = new KFontRequester(groupBox);
        fontrequester->setObjectName("fontrequester");

        verticalLayout_5->addWidget(fontrequester);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        horizontalLayout_3->addWidget(label_5);

        fgcolorbutton = new KColorButton(groupBox);
        fgcolorbutton->setObjectName("fgcolorbutton");

        horizontalLayout_3->addWidget(fgcolorbutton);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        horizontalLayout_3->addWidget(label_6);

        bgcolorbutton = new KColorButton(groupBox);
        bgcolorbutton->setObjectName("bgcolorbutton");

        horizontalLayout_3->addWidget(bgcolorbutton);


        verticalLayout_5->addLayout(horizontalLayout_3);


        verticalLayout_7->addWidget(groupBox);

        label_4 = new QLabel(dockWidgetContents);
        label_4->setObjectName("label_4");

        verticalLayout_7->addWidget(label_4);

        descriptionTextEdit = new QTextEdit(dockWidgetContents);
        descriptionTextEdit->setObjectName("descriptionTextEdit");
        sizePolicy.setHeightForWidth(descriptionTextEdit->sizePolicy().hasHeightForWidth());
        descriptionTextEdit->setSizePolicy(sizePolicy);

        verticalLayout_7->addWidget(descriptionTextEdit);

        qtabwidget = new QTabWidget(dockWidgetContents);
        qtabwidget->setObjectName("qtabwidget");
        tabSprites = new QWidget();
        tabSprites->setObjectName("tabSprites");
        verticalLayout_2 = new QVBoxLayout(tabSprites);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_7 = new QLabel(tabSprites);
        label_7->setObjectName("label_7");

        verticalLayout_2->addWidget(label_7);

        qtabwidget->addTab(tabSprites, QString());
        tabNationalities = new QWidget();
        tabNationalities->setObjectName("tabNationalities");
        verticalLayout_6 = new QVBoxLayout(tabNationalities);
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        newNationalityButton = new QPushButton(tabNationalities);
        newNationalityButton->setObjectName("newNationalityButton");

        horizontalLayout_8->addWidget(newNationalityButton);

        horizontalSpacer_2 = new QSpacerItem(148, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_2);

        deleteNationalityButton = new QPushButton(tabNationalities);
        deleteNationalityButton->setObjectName("deleteNationalityButton");

        horizontalLayout_8->addWidget(deleteNationalityButton);


        verticalLayout_6->addLayout(horizontalLayout_8);

        nationalitieslist = new QListWidget(tabNationalities);
        nationalitieslist->setObjectName("nationalitieslist");

        verticalLayout_6->addWidget(nationalitieslist);

        qtabwidget->addTab(tabNationalities, QString());
        tabCountries = new QWidget();
        tabCountries->setObjectName("tabCountries");
        verticalLayout = new QVBoxLayout(tabCountries);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        newCountryButton = new QPushButton(tabCountries);
        newCountryButton->setObjectName("newCountryButton");

        horizontalLayout_5->addWidget(newCountryButton);

        horizontalSpacer = new QSpacerItem(148, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);

        deleteCountryButton = new QPushButton(tabCountries);
        deleteCountryButton->setObjectName("deleteCountryButton");

        horizontalLayout_5->addWidget(deleteCountryButton);


        verticalLayout->addLayout(horizontalLayout_5);

        countrieslist = new QListWidget(tabCountries);
        countrieslist->setObjectName("countrieslist");

        verticalLayout->addWidget(countrieslist);

        qtabwidget->addTab(tabCountries, QString());
        tabContinents = new QWidget();
        tabContinents->setObjectName("tabContinents");
        verticalLayout_3 = new QVBoxLayout(tabContinents);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        newContinentButton = new QPushButton(tabContinents);
        newContinentButton->setObjectName("newContinentButton");

        horizontalLayout_6->addWidget(newContinentButton);

        horizontalSpacer_3 = new QSpacerItem(148, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_3);

        deleteContinentButton = new QPushButton(tabContinents);
        deleteContinentButton->setObjectName("deleteContinentButton");

        horizontalLayout_6->addWidget(deleteContinentButton);


        verticalLayout_3->addLayout(horizontalLayout_6);

        continentslist = new QListWidget(tabContinents);
        continentslist->setObjectName("continentslist");

        verticalLayout_3->addWidget(continentslist);

        qtabwidget->addTab(tabContinents, QString());
        tabGoals = new QWidget();
        tabGoals->setObjectName("tabGoals");
        verticalLayout_4 = new QVBoxLayout(tabGoals);
        verticalLayout_4->setObjectName("verticalLayout_4");
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        newGoalButton = new QPushButton(tabGoals);
        newGoalButton->setObjectName("newGoalButton");

        horizontalLayout_7->addWidget(newGoalButton);

        horizontalSpacer_4 = new QSpacerItem(148, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_4);

        deleteGoalButton = new QPushButton(tabGoals);
        deleteGoalButton->setObjectName("deleteGoalButton");

        horizontalLayout_7->addWidget(deleteGoalButton);


        verticalLayout_4->addLayout(horizontalLayout_7);

        goalslist = new QListWidget(tabGoals);
        goalslist->setObjectName("goalslist");

        verticalLayout_4->addWidget(goalslist);

        qtabwidget->addTab(tabGoals, QString());

        verticalLayout_7->addWidget(qtabwidget);

        skindefinition->setWidget(dockWidgetContents);

        retranslateUi(skindefinition);

        qtabwidget->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(skindefinition);
    } // setupUi

    void retranslateUi(QDockWidget *skindefinition)
    {
        skindefinition->setWindowTitle(tr2i18n("Skin Definition", nullptr));
        label_3->setText(tr2i18n("Skin name:", nullptr));
#if QT_CONFIG(tooltip)
        skinNameLineEdit->setToolTip(tr2i18n("The skin's short name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        skinNameLineEdit->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        skinNameLineEdit->setWhatsThis(tr2i18n("Type here the skin's short name. This should be an identifier-like string", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Width x height:", nullptr));
#if QT_CONFIG(tooltip)
        widthLineEdit->setToolTip(tr2i18n("Map's width", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        widthLineEdit->setWhatsThis(tr2i18n("This is the map's width. The map SVG element will be by default drawn on an image of this width. All positions on the map are expressed relatively to this dimension.\n"
"", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("x", nullptr));
#if QT_CONFIG(tooltip)
        heightLineEdit->setToolTip(tr2i18n("Map's height", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        heightLineEdit->setWhatsThis(tr2i18n("This is the map's height. The map SVG element will be by default drawn on an image of this height All positions on the map are expressed relatively to this dimension.\n"
"", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox->setTitle(tr2i18n("Map Font", nullptr));
#if QT_CONFIG(tooltip)
        fontrequester->setToolTip(tr2i18n("Font used to draw country names", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        fontrequester->setWhatsThis(tr2i18n("This font will be used to draw the country names on the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_5->setText(tr2i18n("Fg:", nullptr));
#if QT_CONFIG(tooltip)
        fgcolorbutton->setToolTip(tr2i18n("Foreground color for country names", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        fgcolorbutton->setWhatsThis(tr2i18n("This color will be used to draw the foreground of the country names on the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_6->setText(tr2i18n("Bg:", nullptr));
#if QT_CONFIG(tooltip)
        bgcolorbutton->setToolTip(tr2i18n("Background color for country names", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        bgcolorbutton->setWhatsThis(tr2i18n("This color will be used to draw the background of the country names on the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_4->setText(tr2i18n("Description:", nullptr));
#if QT_CONFIG(tooltip)
        descriptionTextEdit->setToolTip(tr2i18n("Human readable description of the skin", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        descriptionTextEdit->setWhatsThis(tr2i18n("Describe here the skin, its style, its story, the intent of its author(s), etc.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        qtabwidget->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        label_7->setText(tr2i18n("Edit the sprite definitions\n"
"in the right dock.", nullptr));
        qtabwidget->setTabText(qtabwidget->indexOf(tabSprites), tr2i18n("Sprites", nullptr));
#if QT_CONFIG(tooltip)
        newNationalityButton->setToolTip(tr2i18n("Creates a new Nationality", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        newNationalityButton->setWhatsThis(tr2i18n("Click here to add a new nationality. You will be prompted for its name.", nullptr));
#endif // QT_CONFIG(whatsthis)
        newNationalityButton->setText(tr2i18n("New Nationality", nullptr));
#if QT_CONFIG(tooltip)
        deleteNationalityButton->setToolTip(tr2i18n("Removes the currently selected nationality", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        deleteNationalityButton->setWhatsThis(tr2i18n("Click here to remove the currently selected nationality. You will be asked for confirmation.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteNationalityButton->setText(tr2i18n("X", nullptr));
#if QT_CONFIG(tooltip)
        nationalitieslist->setToolTip(tr2i18n("Nationality list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        nationalitieslist->setWhatsThis(tr2i18n("This list shows the nationalities defined.\n"
"\n"
"Each nationality name should be unique. Select a nationality and edit its details in the right dock.\n"
"\n"
"During the game, each player must choose a nationality. As such, you should add at least as many nationalities as the maximum number of players for this skin.", nullptr));
#endif // QT_CONFIG(whatsthis)
        qtabwidget->setTabText(qtabwidget->indexOf(tabNationalities), tr2i18n("Nationalities", nullptr));
#if QT_CONFIG(tooltip)
        newCountryButton->setToolTip(tr2i18n("Creates a new country", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        newCountryButton->setWhatsThis(tr2i18n("Click here to add a new country. You will be prompted for its name.", nullptr));
#endif // QT_CONFIG(whatsthis)
        newCountryButton->setText(tr2i18n("New Country", nullptr));
#if QT_CONFIG(tooltip)
        deleteCountryButton->setToolTip(tr2i18n("Removes the currently selected country", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        deleteCountryButton->setWhatsThis(tr2i18n("Click here to remove the currently selected country. You will be asked for confirmation.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteCountryButton->setText(tr2i18n("X", nullptr));
#if QT_CONFIG(tooltip)
        countrieslist->setToolTip(tr2i18n("Country list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        countrieslist->setWhatsThis(tr2i18n("This list shows the countries defined.\n"
"\n"
"Each country name should be unique. Select a country and edit its details in the right dock.", nullptr));
#endif // QT_CONFIG(whatsthis)
        qtabwidget->setTabText(qtabwidget->indexOf(tabCountries), tr2i18n("Countries", nullptr));
#if QT_CONFIG(tooltip)
        newContinentButton->setToolTip(tr2i18n("Creates a new continent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        newContinentButton->setWhatsThis(tr2i18n("Click here to add a new continent. You will be prompted for its name.", nullptr));
#endif // QT_CONFIG(whatsthis)
        newContinentButton->setText(tr2i18n("New Continent", nullptr));
#if QT_CONFIG(tooltip)
        deleteContinentButton->setToolTip(tr2i18n("Removes the currently selected continent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        deleteContinentButton->setWhatsThis(tr2i18n("Click here to remove the currently selected continent. You will be asked for confirmation.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteContinentButton->setText(tr2i18n("X", nullptr));
#if QT_CONFIG(tooltip)
        continentslist->setToolTip(tr2i18n("Continent list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        continentslist->setWhatsThis(tr2i18n("This list shows the continents defined.\n"
"\n"
"Each continent name should be unique. Select a continent and edit its details in the right dock.", nullptr));
#endif // QT_CONFIG(whatsthis)
        qtabwidget->setTabText(qtabwidget->indexOf(tabContinents), tr2i18n("Continents", nullptr));
#if QT_CONFIG(tooltip)
        newGoalButton->setToolTip(tr2i18n("Creates a new goal", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        newGoalButton->setWhatsThis(tr2i18n("Click here to add a new goal. It will be named automatically.", nullptr));
#endif // QT_CONFIG(whatsthis)
        newGoalButton->setText(tr2i18n("New Goal", nullptr));
#if QT_CONFIG(tooltip)
        deleteGoalButton->setToolTip(tr2i18n("Removes the currently selected goal", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        deleteGoalButton->setWhatsThis(tr2i18n("Click here to remove the currently selected goal. You will be asked for confirmation.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteGoalButton->setText(tr2i18n("X", nullptr));
#if QT_CONFIG(tooltip)
        goalslist->setToolTip(tr2i18n("Goal list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        goalslist->setWhatsThis(tr2i18n("This list shows the goals defined.\n"
"\n"
"Each goal name should be unique. Select a goal and edit its details in the right dock.", nullptr));
#endif // QT_CONFIG(whatsthis)
        qtabwidget->setTabText(qtabwidget->indexOf(tabGoals), tr2i18n("Goals", nullptr));
    } // retranslateUi

};

namespace Ui {
    class skindefinition: public Ui_skindefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKSKINDEFINITION_H

